@@ -364,7 +364,7 @@ class SurfingEntrance(object):
                         new_delisted_funds_with_name[fund_id] = fund_name_got.get(fund_id.split('.')[0] + '.OF', None)
                         if new_delisted_funds_with_name[fund_id] is not None:
                             new_delisted_funds_with_name[fund_id] += '(场内)'
-        wechat_bot.send_new_fund_list(yesterday, new_funds_with_name, new_delisted_funds_with_name)
+        wechat_bot.send_new_fund_list(yesterday, new_funds_with_name, new_delisted_funds_with_name, RawDataHelper.get_indexes_that_become_invalid(yesterday))
 
     def dump_tables_and_dfs(self, yesterday=None, wechat_bot=None):
         from .data.manager.etl_tool import SynchronizerS3ForDM
@@ -374,7 +374,7 @@ class SurfingEntrance(object):
         # 构建一个默认的DM
         try:
             fdm = FundDataManager()
-            fdm.init(score_pre_calc=True, print_time=True, use_weekly_monthly_indicators=False)
+            fdm.init(score_pre_calc=True, print_time=True, use_weekly_monthly_indicators=False, block_df_list=[])
         except Exception as e:
             print(f'init dm failed (err_msg){e}')
 
