@@ -1,7 +1,7 @@
+
 import inspect
 import enum
 
-
 INDEX_PRICE_EXTRA_TRADE_DAYS = 15
 FUND_NAV_EXTRA_TRADE_DAYS = 5
 
@@ -34,6 +34,46 @@ class ReadableEnum(object):
         return cls._code_name_cache[1].get(code, code)
 
 
+class SourceType(enum.IntEnum):
+    qieman = 1  # 且慢
+    danjuan = 2  # 蛋卷
+    em = 3  # 天天基金
+    gf_sec = 4  # 广发基金
+
+    # 以下为手工爬取部分
+    bcm = 8192  # 交通银行
+    ccb = 8193  # 建设银行
+    cgb = 8194  # 广发银行
+    citics = 8195  # 中信证券
+    citicb = 8196  # 中信银行
+    cmbc = 8197  # 民生银行
+    gtjas = 8198  # 国泰君安
+    guosens = 8199  # 国信证券
+    icbc = 8200  # 工商银行
+    pinganb = 8201  # 平安银行
+    spdb = 8202  # 浦发银行
+
+    @staticmethod
+    def get_names_of_type():
+        return {
+            SourceType.qieman: '且慢',
+            SourceType.danjuan: '蛋卷',
+            SourceType.em: '天天基金',
+            SourceType.gf_sec: '广发基金',
+            SourceType.bcm: '交通银行',
+            SourceType.ccb: '建设银行',
+            SourceType.cgb: '广发银行',
+            SourceType.citics: '中信证券',
+            SourceType.citicb: '中信银行',
+            SourceType.cmbc: '民生银行',
+            SourceType.gtjas: '国泰君安',
+            SourceType.guosens: '国信证券',
+            SourceType.icbc: '工商银行',
+            SourceType.pinganb: '平安银行',
+            SourceType.spdb: '浦发银行',
+        }
+
+
 # 板块类型
 class SectorType(enum.IntEnum):
     industry = 1
