@@ -203,24 +203,25 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'Failed to delete data <err_msg> {e} from {FundNav.__tablename__}')
                 return None
 
-    def get_fund_nav_with_date(self, start_date, end_date, fund_list: Tuple[str] = ()):
+    def get_fund_nav_with_date(self, start_date='', end_date='', fund_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
-                        FundNav.fund_id,
-                        FundNav.adjusted_net_value,
-                        FundNav.datetime
-                    )
+                    FundNav.fund_id,
+                    FundNav.adjusted_net_value,
+                    FundNav.datetime
+                )
                 if fund_list:
                     query = query.filter(FundNav.fund_id.in_(fund_list))
-                query = query.filter(
-                    FundNav.datetime >= start_date,
-                    FundNav.datetime <= end_date,
-                )
-
-                tag_df = pd.read_sql(query.statement, query.session.bind)
-                return tag_df
-
+                if start_date:
+                    query = query.filter(
+                        FundNav.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        FundNav.datetime <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundNav.__tablename__}')
 
@@ -278,12 +279,22 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {IndexPrice.__tablename__}')
 
-    def get_index_price_dt(self, start_date: str = '', end_date: str = ''):
+    def get_index_price_dt(self, start_date: str = '', end_date: str = '', index_list: Tuple[str] = (), columns: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
-                query = db_session.query(
-                    IndexPrice
-                )
+                if columns:
+                    query = db_session.query(
+                        IndexPrice.index_id,
+                        IndexPrice.datetime,
+                    ).add_columns(*columns)
+                else:
+                    query = db_session.query(
+                        IndexPrice
+                    )
+                if index_list:
+                    query = query.filter(
+                        IndexPrice.index_id.in_(index_list),
+                    )
                 if start_date:
                     query = query.filter(
                         IndexPrice.datetime >= start_date,
@@ -416,7 +427,7 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {FundStatusLatest.__tablename__}')
 
     @staticmethod
-    def get_history_fund_size(fund_id: str = ''):
+    def get_history_fund_size(fund_id: str = '', start_date=None, end_date=None):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
@@ -426,23 +437,52 @@ class BasicDataApi(metaclass=Singleton):
                     query = query.filter(
                         Fund_size_and_hold_rate.fund_id == fund_id
                     )
+                if start_date is not None:
+                    query = query.filter(
+                        Fund_size_and_hold_rate.datetime >= start_date,
+                    )
+                if end_date is not None:
+                    query = query.filter(
+                        Fund_size_and_hold_rate.datetime <= end_date,
+                    )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {Fund_size_and_hold_rate.__tablename__}')
                 return pd.DataFrame([])
 
     @staticmethod
-    def get_fund_size_range(start_date, end_date):
+    def get_fund_size_range(start_date='', end_date='', fund_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     Fund_size_and_hold_rate.fund_id,
                     Fund_size_and_hold_rate.datetime,
                     Fund_size_and_hold_rate.size,
-                ).filter(
-                    # 按报告日多选取3个月，保证初值可以fill出来
-                    Fund_size_and_hold_rate.datetime >= (pd.to_datetime(start_date) - datetime.timedelta(days=100)).strftime('%Y%m%d'),
-                    Fund_size_and_hold_rate.datetime <= end_date,
+                )
+                if fund_list:
+                    query = query.filter(
+                        Fund_size_and_hold_rate.fund_id.in_(fund_list),
+                    )
+                if start_date:
+                    query = query.filter(
+                        # 按报告日多选取3个月，保证初值可以fill出来
+                        Fund_size_and_hold_rate.datetime >= (pd.to_datetime(start_date) - datetime.timedelta(days=100)).strftime('%Y%m%d'),
+                    )
+                if end_date:
+                    query = query.filter(
+                        Fund_size_and_hold_rate.datetime <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {Fund_size_and_hold_rate.__tablename__}')
+                return pd.DataFrame([])
+
+    @staticmethod
+    def get_fund_size_all_data():
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    Fund_size_and_hold_rate
                 )
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
@@ -468,7 +508,7 @@ class BasicDataApi(metaclass=Singleton):
                 return pd.DataFrame([])
 
     @staticmethod
-    def get_fund_hold_asset_by_id(fund_id: str = ''):
+    def get_fund_hold_asset_by_id(fund_id: str = '', start_date=None, end_date=None):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
@@ -478,9 +518,15 @@ class BasicDataApi(metaclass=Singleton):
                     query = query.filter(
                         FundHoldAsset.fund_id == fund_id,
                     )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
-
+                if start_date is not None:
+                    query = query.filter(
+                        FundHoldAsset.datetime >= start_date,
+                    )
+                if end_date is not None:
+                    query = query.filter(
+                        FundHoldAsset.datetime <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundHoldAsset.__tablename__}')
                 return pd.DataFrame([])
