@@ -63,7 +63,7 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundIndicatorMonthly.__tablename__}')
 
-    def get_fund_indicator_group(self, start_date: str, end_date: str):
+    def get_fund_indicator_group(self, start_date: str, end_date: str, data_cycle: str = ''):
         with DerivedDatabaseConnector().managed_session() as quant_session:
             try:
                 query = quant_session.query(
@@ -73,6 +73,35 @@ class DerivedDataApi(metaclass=Singleton):
                     FundIndicatorGroup.datetime >= start_date,
                     FundIndicatorGroup.datetime <= end_date
                 )
+                if data_cycle:
+                    query = query.filter(
+                        FundIndicatorGroup.data_cycle == data_cycle
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundIndicatorGroup.__tablename__}')
+
+    def get_latest_fund_indicator_group(self, data_cycle: str = ''):
+        with DerivedDatabaseConnector().managed_session() as quant_session:
+            try:
+                sub_q = quant_session.query(
+                    FundIndicatorGroup.datetime.label('latest_time'),
+                )
+                if data_cycle:
+                    sub_q = sub_q.filter(
+                        FundIndicatorGroup.data_cycle == data_cycle,
+                    )
+                sub_q = sub_q.order_by(
+                    FundIndicatorGroup.datetime.desc(),
+                ).limit(1).subquery()
+
+                query = quant_session.query(FundIndicatorGroup).filter(
+                    FundIndicatorGroup.datetime == sub_q.c.latest_time,
+                )
+                if data_cycle:
+                    query = query.filter(
+                        FundIndicatorGroup.data_cycle == data_cycle,
+                    )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundIndicatorGroup.__tablename__}')
@@ -89,27 +118,28 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundScore.__tablename__}')
 
-    def get_fund_score_extended_by_id(self, fund_id):
+    def get_fund_score_extended_by_id(self, fund_id, data_cycle: str = '1Y'):
         with DerivedDatabaseConnector().managed_session() as quant_session:
             try:
                 query = quant_session.query(
                     FundScoreExtended,
                 ).filter(
                     FundScoreExtended.fund_id == fund_id,
+                    FundScoreExtended.data_cycle == data_cycle,
                 )
-
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundScoreExtended.__tablename__}')
                 return pd.DataFrame([])
 
-    def get_latest_fund_score_new_by_id(self, fund_id):
+    def get_latest_fund_score_new_by_id(self, fund_id, data_cycle: str = '1Y'):
         with DerivedDatabaseConnector().managed_session() as quant_session:
             try:
                 query = quant_session.query(
                     FundScoreNew,
                 ).filter(
                     FundScoreNew.fund_id == fund_id,
+                    FundScoreNew.data_cycle == data_cycle,
                 ).order_by(
                     FundScoreNew.datetime.desc()
                 ).limit(1)
@@ -119,7 +149,7 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {FundScoreNew.__tablename__}')
                 return pd.DataFrame([])
 
-    def get_fund_score_extended(self, start_date: str, end_date: str, fund_list: Tuple[str] = (), columns: Tuple[str] = ()):
+    def get_fund_score_extended(self, start_date: str, end_date: str, fund_list: Tuple[str] = (), columns: Tuple[str] = (), data_cycle: str = '1Y'):
         with DerivedDatabaseConnector().managed_session() as quant_session:
             try:
                 if columns:
@@ -139,6 +169,7 @@ class DerivedDataApi(metaclass=Singleton):
                 query = query.filter(
                     FundScoreExtended.datetime >= start_date,
                     FundScoreExtended.datetime <= end_date,
+                    FundScoreExtended.data_cycle == data_cycle,
                 )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
@@ -398,3 +429,66 @@ class DerivedDataApi(metaclass=Singleton):
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundManagerInfo.__tablename__}')
+
+    def get_market_portfolio_indicator(self):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    ThirdPartyPortfolioIndicator
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_market_portfolio_indicator {e} from {ThirdPartyPortfolioIndicator.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_market_portfolio_info(self):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    ThirdPartyPortfolioInfo
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_market_portfolio_info {e} from {ThirdPartyPortfolioInfo.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_market_portfolio_trade_dates(self, po_id):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    ThirdPartyPortfolioTrade.datetime
+                ).filter(
+                    ThirdPartyPortfolioTrade.po_id == po_id,
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_market_portfolio_trade_dates {e} from {ThirdPartyPortfolioTrade.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_market_portfolio_trade_by_date(self, po_id, date):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    ThirdPartyPortfolioTrade
+                ).filter(
+                    ThirdPartyPortfolioTrade.po_id == po_id,
+                    ThirdPartyPortfolioTrade.datetime == date,
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_market_portfolio_trade_by_date {e} from {ThirdPartyPortfolioTrade.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_market_portfolio_position(self, po_id):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    ThirdPartyPortfolioPositionLatest
+                ).filter(
+                    ThirdPartyPortfolioPositionLatest.po_id == po_id,
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_market_portfolio_position {e} from {ThirdPartyPortfolioPositionLatest.__tablename__}')
+                return pd.DataFrame([])
+
