@@ -454,12 +454,15 @@ class RawDataApi(metaclass=Singleton):
     def get_em_stock_price(self, start_date: str, end_date: str, stock_list: Tuple[str] = (), columns: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
-                query = db_session.query(
-                    EmStockPrice.CODES,
-                    EmStockPrice.DATES,
-                )
                 if columns:
-                    query = query.add_columns(*columns)
+                    query = db_session.query(
+                        EmStockPrice.CODES,
+                        EmStockPrice.DATES,
+                    ).add_columns(*columns)
+                else:
+                    query = db_session.query(
+                        EmStockPrice
+                    )
                 if stock_list:
                     query = query.filter(
                         EmStockPrice.CODES.in_(stock_list)
@@ -476,12 +479,15 @@ class RawDataApi(metaclass=Singleton):
     def get_em_stock_post_price(self, start_date: str, end_date: str, stock_list: Tuple[str] = (), columns: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
-                query = db_session.query(
-                    EmStockPostPrice.CODES,
-                    EmStockPostPrice.DATES,
-                )
                 if columns:
-                    query = query.add_columns(*columns)
+                    query = db_session.query(
+                        EmStockPostPrice.CODES,
+                        EmStockPostPrice.DATES,
+                    ).add_columns(*columns)
+                else:
+                    query = db_session.query(
+                        EmStockPostPrice,
+                    )
                 if stock_list:
                     query = query.filter(
                         EmStockPostPrice.CODES.in_(stock_list)
@@ -597,7 +603,7 @@ class RawDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {EmIndexInfo.__tablename__}')
                 return None
 
-    def get_em_index_component(self, start_date: str, end_date: str, index_list: Tuple[str] = ()):
+    def get_em_index_component(self, start_date: str = '', end_date: str = '', index_list: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
@@ -607,10 +613,14 @@ class RawDataApi(metaclass=Singleton):
                     query = query.filter(
                         EmIndexComponent.index_id.in_(index_list)
                     )
-                query = query.filter(
-                    EmIndexComponent.datetime >= start_date,
-                    EmIndexComponent.datetime <= end_date,
-                )
+                if start_date:
+                    query = query.filter(
+                        EmIndexComponent.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmIndexComponent.datetime <= end_date,
+                    )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmIndexComponent.__tablename__}')
@@ -1037,3 +1047,41 @@ class RawDataApi(metaclass=Singleton):
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmMacroEconomicDaily.__tablename__}')
+
+    def get_em_fund_open(self):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EmFundOpen)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EmFundOpen.__tablename__}') 
+
+    def get_em_fund_ipo_status(self):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EmFundIPOStats)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EmFundIPOStats.__tablename__}')
+
+    def get_em_stock_industrial_capital(self):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EmStockIndustrialCapital)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EmStockIndustrialCapital.__tablename__}')
+
+    def delete_em_stock_industrial_capital(self, the_date, period: str):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmStockIndustrialCapital
+                ).filter(
+                    EmStockIndustrialCapital.datetime == the_date,
+                    EmStockIndustrialCapital.period == period,
+                ).delete(synchronize_session=False)
+                db_session.commit()
+                return True
+            except Exception as e:
+                print(f'Failed to delete data <err_msg> {e} from {EmStockIndustrialCapital.__tablename__}')
