@@ -704,13 +704,13 @@ class BasicDataPart1:
             return False
 
     def fund_size_hold_rate_history(self):
-        start_date = '20040331'
-        end_date = '20100331'
-        raw = self._raw_data_api
+        start_date = '20200630'
+        end_date = '20200630'
 
-        fund_holding_rate = raw.get_em_fund_holding_rate(start_date=start_date, end_date=end_date)
+        fund_holding_rate = self._raw_data_api.get_em_fund_holding_rate(start_date=start_date, end_date=end_date)
         fund_holding_rate['fund_id'] = fund_holding_rate.apply(
             lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
+        fund_holding_rate = fund_holding_rate[fund_holding_rate.fund_id.notna()]
         fund_holding_rate = fund_holding_rate.drop(['CODES', '_update_time'], axis=1).rename(columns={
             'DATES': 'datetime',
             'HOLDPERSONALHOLDINGPCT': 'personal_holds',
@@ -719,11 +719,12 @@ class BasicDataPart1:
         })
         fund_holding_rate = fund_holding_rate[fund_holding_rate.drop(columns='fund_id').notna().any(axis=1)]
 
-        fund_scale = raw.get_em_fund_scale(start_date=start_date, end_date=end_date)
+        fund_scale = self._raw_data_api.get_em_fund_scale(start_date=start_date, end_date=end_date)
         fund_scale = fund_scale.pivot(index='DATES', columns='CODES', values='FUNDSCALE').fillna(method='ffill').stack()
         fund_scale = pd.DataFrame(fund_scale, columns=['FUNDSCALE']).reset_index()
         fund_scale['fund_id'] = fund_scale.apply(
             lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
+        fund_scale = fund_scale[fund_scale.fund_id.notna()]
         fund_scale = fund_scale.drop(['CODES'], axis=1).rename(columns={'DATES': 'datetime', 'FUNDSCALE': 'size'})
         fund_scale = fund_scale.dropna().drop_duplicates(subset=['size', 'fund_id'], keep='first')
 
@@ -813,6 +814,14 @@ class BasicDataPart1:
         df = df.drop('code',axis=1).dropna(subset=['fund_id'])
         self._data_helper._upload_basic(df, FundCompCoreMng.__table__.name)
 
+    def fund_open_info(self):
+        df = self._raw_data_api.get_em_fund_open()
+        df['fund_id'] = df.apply(
+            lambda x : self._data_helper._get_fund_id_from_order_book_id(x.em_id.split('.')[0], datetime.date(2020,9,15)), axis = 1)       
+        df = df.dropna(subset=['fund_id'])
+        df = df.drop(['em_id','_update_time'],axis=1)
+        self._data_helper._upload_basic(df, FundOpenInfo.__table__.name)
+
     def process_all(self, start_date, end_date):
         failed_tasks = []
         # Depend on RQ
