@@ -15,6 +15,7 @@ from .derived_indicators_processor_group import FundIndicatorProcessorGroup
 from .derived_index_ret_vol import IndexIndicatorProcessor
 from .derived_fund_aic import AIPProcess
 from .derived_mng_fund_rank import FundManagerFundRankProcessor
+from .derived_fund_alpha import FundAlphaProcessor
 # from .derived_fund_score_extended import FundScoreExtendedProcess
 from .derived_fund_score_group import FundScoreGroupProcess
 from .derived_fund_score_group_v1 import FundScoreGroupV1Process
@@ -22,6 +23,8 @@ from .barra_cne5_factor_processor import BarraCNE5FactorProcessor
 from .style_reg_processer import StyleBoxReg
 from .style_box import StyleBoxGenerator
 from .fund_manager_processor import ManagerProcessor
+from .fund_indicator_processor_ipo_conv import FundIndicatorProcessorIPOConv
+from .derived_top_manager_funds import TopManagerFundProcessor
 from ...api.basic import BasicDataApi
 
 
@@ -31,7 +34,8 @@ class DerivedDataProcessor:
         self.fund_indicator_processor = FundIndicatorProcessor(self._data_helper)
         self.fund_indicator_processor_weekly = FundIndicatorProcessorWeekly(self._data_helper)
         self.fund_indicator_processor_monthly = FundIndicatorProcessorMonthly(self._data_helper)
-        self.fund_indicator_processor_group = FundIndicatorProcessorGroup(self._data_helper)
+        self.fund_indicator_processor_group_1Y = FundIndicatorProcessorGroup(self._data_helper, 1)
+        self.fund_indicator_processor_group_5Y = FundIndicatorProcessorGroup(self._data_helper, 5)
         self._manager_processor = ManagerProcessor(self._data_helper)
         # self.index_val_processor = IndexValProcess(self._data_helper)
         self.index_val_processor_long_term = IndexValProcessLongTerm(self._data_helper)
@@ -39,13 +43,18 @@ class DerivedDataProcessor:
         self.fund_aip = AIPProcess(self._data_helper)
         # 这版基金评分先不用了，这里先注释掉
         # self._derived_fund_score_extended = FundScoreExtendedProcess(self._data_helper)
-        self._derived_fund_score_group_v1 = FundScoreGroupV1Process(self._data_helper)
-        self._derived_fund_score_group = FundScoreGroupProcess(self._data_helper)
+        self._derived_fund_score_group_v1_1Y = FundScoreGroupV1Process(self._data_helper, 1)
+        self._derived_fund_score_group_v1_5Y = FundScoreGroupV1Process(self._data_helper, 5)
+        self._derived_fund_score_group_1Y = FundScoreGroupProcess(self._data_helper, 1)
+        self._derived_fund_score_group_5Y = FundScoreGroupProcess(self._data_helper, 5)
         self._barra_cne5_factor_processor = BarraCNE5FactorProcessor(self._data_helper)
         self._style_regression_processor = StyleBoxReg(self._data_helper)
         self._style_box_processor = StyleBoxGenerator(self._data_helper)
         self.style_analysis_processors: List[StyleAnalysisProcessor] = []
         self.mng_fund_rank = FundManagerFundRankProcessor(self._data_helper)
+        self._fund_alpha_processor = FundAlphaProcessor(self._data_helper)
+        self.fund_indicator_processor_ipo_conv = FundIndicatorProcessorIPOConv(self._data_helper)
+        self.top_manager_funds_processor = TopManagerFundProcessor(self._data_helper)
         # 暂时只算这三个universe
         for universe in ('hs300', 'csi800', 'all'):
             sap = StyleAnalysisProcessor(self._data_helper, universe)
@@ -61,8 +70,11 @@ class DerivedDataProcessor:
         failed_tasks.extend(self.fund_aip.process(start_date, end_date))
         failed_tasks.extend(self._barra_cne5_factor_processor.process(start_date, end_date))
         failed_tasks.extend(self._style_regression_processor.process(start_date, end_date))
-        failed_tasks.extend(self._style_box_processor.process(start_date, end_date))
+        # failed_tasks.extend(self._style_box_processor.process(start_date, end_date))
         failed_tasks.extend(self.mng_fund_rank.process(end_date))
+        failed_tasks.extend(self._fund_alpha_processor.process(start_date, end_date))
+        failed_tasks.extend(self.fund_indicator_processor_ipo_conv.process(start_date, end_date))
+        failed_tasks.extend(self.top_manager_funds_processor.process(start_date, end_date))
         for sap in self.style_analysis_processors:
             failed_tasks.extend(sap.process(start_date, end_date))
 
@@ -82,10 +94,14 @@ class DerivedDataProcessor:
                 print(f'weekly indicator only update on the last day of week, not today {end_date_dt}')
             else:
                 failed_tasks.extend(self.fund_indicator_processor_weekly.process(start_date, end_date, end_date_dt))
-                failed_tasks.extend(self.fund_indicator_processor_group.process(start_date, end_date, end_date_dt))
+                # 分别用2年和5年的数据算一下
+                failed_tasks.extend(self.fund_indicator_processor_group_1Y.process(start_date, end_date, end_date_dt))
+                failed_tasks.extend(self.fund_indicator_processor_group_5Y.process(start_date, end_date, end_date_dt))
                 # failed_tasks.extend(self._derived_fund_score_extended.process(start_date, end_date, end_date_dt))
-                failed_tasks.extend(self._derived_fund_score_group_v1.process(start_date, end_date, end_date_dt))
-                failed_tasks.extend(self._derived_fund_score_group.process(start_date, end_date, end_date_dt))
+                failed_tasks.extend(self._derived_fund_score_group_v1_1Y.process(start_date, end_date, end_date_dt))
+                failed_tasks.extend(self._derived_fund_score_group_v1_5Y.process(start_date, end_date, end_date_dt))
+                failed_tasks.extend(self._derived_fund_score_group_1Y.process(start_date, end_date, end_date_dt))
+                failed_tasks.extend(self._derived_fund_score_group_5Y.process(start_date, end_date, end_date_dt))
 
             if end_date_dt.year == next_trading_dt.year and end_date_dt.month == next_trading_dt.month:
                 # 表明本月后边还有交易日，今天不需要更新
