@@ -125,6 +125,8 @@ class IndexIndicatorProcessor:
     def _process_result(self, result):
         _res = []
         for k, df in result.items():
+            if df.empty:
+                continue
             _res.append(pd.DataFrame(df.stack()).rename(columns={0: k}))
         self.result = pd.concat(_res, axis=1, sort=False).reset_index()
 
@@ -242,11 +244,9 @@ class IndexIndicatorProcessor:
 
 if __name__ == '__main__':
     from .derived_data_helper import DerivedDataHelper
-
-    trading_days = BasicDataApi().get_trading_day_list('20200713', '20200821')
     iip = IndexIndicatorProcessor(DerivedDataHelper())
-    for date in trading_days.datetime:
-        date = date.strftime('%Y%m%d')
-        print(f'deal with {date}')
-        if iip.process(date):
-            break
+    iip.process('20200925')
+
+    # iip.history_init()
+    # iip.process_ret_history()
+    # iip.process_vol_history()
