@@ -9,6 +9,8 @@ import json
 import statsmodels.api as sm
 from scipy.optimize import Bounds, minimize
 from statsmodels.tsa.ar_model import AutoReg
+from pandas.tseries.offsets import DateOffset
+
 from ...api.basic import BasicDataApi
 from ...view.derived_models import FundIndicatorGroup
 from .derived_data_helper import DerivedDataHelper
@@ -17,21 +19,24 @@ from .derived_data_helper import DerivedDataHelper
 class FundIndicatorProcessorGroup:
 
     _TRADING_DAYS_PER_YEAR = 242
-    _NATURAL_DAYS_PER_YEAR = 365
+    _NATURAL_DAYS_PER_YEAR = 360
     _RISK_FEE_RATE = 0.011
     _RISK_FEE_RATE_PER_DAY = _RISK_FEE_RATE / _TRADING_DAYS_PER_YEAR
     _REPORT_DATE_LIST = ['0331', '0630', '0930', '1231']
 
-    def __init__(self, data_helper: DerivedDataHelper):
+    def __init__(self, data_helper: DerivedDataHelper, data_cycle: int):
         self._data_helper = data_helper
+        # 单位: 年
+        self._data_cycle = data_cycle
+        self._data_cycle_days = data_cycle * self._TRADING_DAYS_PER_YEAR
         self._basic_api = BasicDataApi()
         self._rank_dic: Dict[pd.DataFrame] = {}
         self._res: List[pd.Series] = []
 
-    def init(self, start_date: str, end_date: str):
+    def init(self, end_date: str):
         # self.log = []
-        # 向前取2年
-        start_date: str = (pd.to_datetime(start_date, infer_datetime_format=True) - datetime.timedelta(days=self._NATURAL_DAYS_PER_YEAR*2+1)).strftime('%Y%m%d')
+        # 向前取N年
+        start_date: str = (pd.to_datetime(end_date, infer_datetime_format=True) - DateOffset(years=self._data_cycle+1)).strftime('%Y%m%d')
         print(f'start date for data: {start_date}')
         # 获取区间内交易日列表
         all_trading_days: pd.Series = self._basic_api.get_trading_day_list().drop(columns='_update_time').set_index('datetime')
@@ -52,10 +57,10 @@ class FundIndicatorProcessorGroup:
                         res.append(fund_id)
         self._fund_nav = self._fund_nav[res].copy()
 
-        index_price: pd.DataFrame = self._basic_api.get_index_price_dt(start_date, end_date).drop(columns='_update_time')
+        index_price: pd.DataFrame = self._basic_api.get_index_price_dt(start_date, end_date, columns=['close'])
         # 有的index最近没有数据，如活期存款利率/各种定期存款利率等，需要先reindex到全部的交易日列表上ffill
         self._index_price: pd.DataFrame = index_price.pivot_table(index='datetime', columns='index_id', values='close').reindex(self._trading_days.index).fillna(method='ffill')
-        _bank_rate_df: pd.DataFrame = self._basic_api.get_index_price(index_list=['ddir', 'nonor', 'tmd_1y', 'tmd_2y', 'tmd_3m', 'tmd_3y', 'tmd_5y', 'tmd_6m', 'tmd_7d']).drop(columns='_update_time')
+        _bank_rate_df: pd.DataFrame = self._basic_api.get_index_price(index_list=['ddir', 'nonor', 'tmd_1y', 'tmd_2y', 'tmd_3m', 'tmd_3y', 'tmd_5y', 'tmd_6m', 'tmd_7d'])
         _bank_rate_df = _bank_rate_df.pivot_table(index='datetime', columns='index_id', values='close').reindex(all_trading_days.index).fillna(method='ffill').reindex(self._trading_days.index)
         drop_list = [i for i in self._index_price if i in _bank_rate_df]
         self._index_price = self._index_price.drop(drop_list, axis=1)
@@ -73,29 +78,34 @@ class FundIndicatorProcessorGroup:
         self._fund_ret: pd.DataFrame = np.log(self._fund_nav).diff().iloc[1:, :]
 
         self._fund_size: pd.DataFrame = self._basic_api.get_fund_size_range(start_date, end_date)
-        self._fund_size = self._fund_size.pivot_table(index='datetime', columns='fund_id', values='size').reindex(self._fund_ret.index).fillna(method='ffill')
+        self._fund_size = self._fund_size.pivot_table(index='datetime', columns='fund_id', values='size')
+        self._fund_size = self._fund_size.reindex(self._fund_ret.index.union(self._fund_size.index)).fillna(method='ffill').reindex(self._fund_ret.index)
         pd.testing.assert_index_equal(self._fund_ret.index, self._fund_size.index)
 
         # 计算benchmark return，且index对齐到fund_ret
+        self._fund_benchmark_df: pd.DataFrame = self._basic_api.get_fund_benchmark().drop(columns='_update_time')
         benchmark_ret: pd.DataFrame = self._get_benchmark_return()
         self._benchmark_ret: pd.DataFrame = benchmark_ret.reindex(self._fund_ret.index)
         pd.testing.assert_index_equal(self._fund_ret.index, self._benchmark_ret.index)
+        self._fund_ret = self._fund_ret.join(self._benchmark_ret, rsuffix='_b')
 
         # 获取待计算的基金列表
         fund_list: pd.DataFrame = self._basic_api.get_fund_info().drop(columns='_update_time')
         self._fund_list: pd.DataFrame = fund_list[fund_list.structure_type <= 1]
         # 获取wind一级分类
         self._wind_class_1: np.ndarray = fund_list.wind_class_1.unique()
-        # 按wind二级分类计算分类呢基金收益率排名
+        # 按wind二级分类计算基金收益率排名
         self._get_continue_stats_tool()
         # 取出沪深300收益率
-        self._hs300 = self._basic_api.get_index_price(tuple(['hs300']))[['datetime','close']]
-        self._hs300 = self._hs300.set_index(self._hs300.datetime)['close']
+        self._hs300 = self._basic_api.get_index_price(['hs300'])[['datetime', 'close']]
+        self._hs300 = self._hs300.set_index('datetime')['close']
         self._hs300 = self._hs300.apply(np.log).diff()[1:]
+        self._fund_ret = self._fund_ret.join(self._hs300.rename('close_hs300'))
         # 取出货币基金指数收益率
-        self._mmf = self._basic_api.get_index_price(tuple(['mmf']))[['datetime','close']]
-        self._mmf = self._mmf.set_index(self._mmf.datetime)['close']
+        self._mmf = self._basic_api.get_index_price(['mmf'])[['datetime', 'close']]
+        self._mmf = self._mmf.set_index('datetime')['close']
         self._mmf = self._mmf.apply(np.log).diff()[1:]
+        self._fund_ret = self._fund_ret.join(self._mmf.rename('close_mmf'))
         # 获取年报/半年报的发布日期
         end_date_dt = pd.to_datetime(end_date, infer_datetime_format=True)
         md = end_date_dt.strftime('%m%d')
@@ -110,11 +120,112 @@ class FundIndicatorProcessorGroup:
             real_date = datetime.date(end_date_dt.year, 6, 30)
 
         # 取出持仓数据
-        self._fund_hold = self._basic_api.get_history_fund_size()
-        self._fund_hold = self._fund_hold[self._fund_hold.datetime == real_date][['fund_id','institution_holds','hold_num']].reset_index()
+        self._fund_hold = self._basic_api.get_history_fund_size(start_date=real_date, end_date=real_date)
+        self._fund_hold = self._fund_hold[['fund_id', 'institution_holds', 'hold_num']].set_index('fund_id')
         # 取出货基风险相关数据
-        self._risk_metric = self._basic_api.get_fund_hold_asset_by_id()
-        self._risk_metric = self._risk_metric[self._risk_metric.datetime == real_date][['fund_id','first_repo_to_nav','avg_ptm']].reset_index()
+        self._risk_metric = self._basic_api.get_fund_hold_asset_by_id(start_date=real_date, end_date=real_date)
+        self._risk_metric = self._risk_metric[['fund_id', 'first_repo_to_nav', 'avg_ptm']].set_index('fund_id')
+
+    def history_load_data(self, end_date):
+        # 获取区间内交易日列表
+        self._trading_days_all: pd.Series = self._basic_api.get_trading_day_list().drop(columns='_update_time').set_index('datetime')
+        # 基金净值数据、指数价格数据的index对齐到交易日列表
+        self._fund_nav_all: pd.DataFrame = self._basic_api.get_fund_nav_with_date(end_date=end_date)
+        self._fund_nav_all = self._fund_nav_all.pivot_table(index='datetime', columns='fund_id', values='adjusted_net_value')
+        self._index_price_all: pd.DataFrame = self._basic_api.get_index_price_dt(end_date=end_date, columns=['close'])
+        self._index_price_all = self._index_price_all.pivot_table(index='datetime', columns='index_id', values='close')
+        _bank_rate_df: pd.DataFrame = self._basic_api.get_index_price(index_list=['ddir', 'nonor', 'tmd_1y', 'tmd_2y', 'tmd_3m', 'tmd_3y', 'tmd_5y', 'tmd_6m', 'tmd_7d'])
+        self._bank_rate_df = _bank_rate_df.pivot_table(index='datetime', columns='index_id', values='close').reindex(self._trading_days_all.index).fillna(method='ffill')
+        drop_list = [i for i in self._index_price_all if i in self._bank_rate_df]
+        self._index_price_all = self._index_price_all.drop(columns=drop_list)
+        self._fund_size: pd.DataFrame = self._basic_api.get_fund_size_range(end_date=end_date)
+        self._fund_size = self._fund_size.pivot_table(index='datetime', columns='fund_id', values='size')
+        # 获取待计算的基金列表
+        fund_list: pd.DataFrame = self._basic_api.get_fund_info().drop(columns='_update_time')
+        self._fund_list: pd.DataFrame = fund_list[fund_list.structure_type <= 1]
+        # 获取wind一级分类
+        self._wind_class_1: np.ndarray = fund_list.wind_class_1.unique()
+        # 取出沪深300收益率
+        self._hs300 = self._basic_api.get_index_price(['hs300'])[['datetime', 'close']]
+        self._hs300 = self._hs300.set_index('datetime')['close']
+        self._hs300 = self._hs300.apply(np.log).diff()[1:]
+        # 取出货币基金指数收益率
+        self._mmf = self._basic_api.get_index_price(['mmf'])[['datetime', 'close']]
+        self._mmf = self._mmf.set_index('datetime')['close']
+        self._mmf = self._mmf.apply(np.log).diff()[1:]
+        self._fund_benchmark_df: pd.DataFrame = self._basic_api.get_fund_benchmark().drop(columns='_update_time')
+
+    def history_init(self, end_date):
+        start_date: datetime.date = (pd.to_datetime(end_date, infer_datetime_format=True) - DateOffset(years=self._data_cycle+1)).date()
+        print(f'start date for data: {start_date}')
+        end_date: datetime.date = pd.to_datetime(end_date, infer_datetime_format=True).date()
+
+        _trading_days: pd.Series = self._trading_days_all.loc[start_date:end_date]
+        # 使用实际trading day的最后一天作为end_date
+        self.end_date = _trading_days.index.array[-1]
+
+        # 基金净值数据、指数价格数据的index对齐到交易日列表
+        fund_nav: pd.DataFrame = self._fund_nav_all.loc[start_date:end_date, :]
+        self._fund_nav: pd.DataFrame = fund_nav.reindex(_trading_days.index).fillna(method='ffill')
+        # 选取成立满半年的 而且近半年波动率不为0，并排除掉异常净值基金
+        res = []
+        for fund_id in self._fund_nav:
+            _df = self._fund_nav[fund_id].dropna()
+            if _df.shape[0] > 120:
+                if _df.iloc[-120:].var() > 1e-6:
+                    if _df.pct_change(1).abs().max() < 0.2:
+                        res.append(fund_id)
+        self._fund_nav = self._fund_nav[res].copy()
+
+        index_price: pd.DataFrame = self._index_price_all.loc[start_date:end_date, :]
+        # 有的index最近没有数据，如活期存款利率/各种定期存款利率等，需要先reindex到全部的交易日列表上ffill
+        self._index_price: pd.DataFrame = index_price.reindex(_trading_days.index).fillna(method='ffill')
+        _bank_rate_df = self._bank_rate_df.reindex(_trading_days.index)
+        self._index_price: pd.DataFrame = pd.concat([self._index_price, _bank_rate_df], axis=1).dropna(how='all', axis=1)
+        # 再reindex到参与计算的交易日列表上
+        # self._index_price: pd.DataFrame = index_price.reindex(_trading_days.index)
+        pd.testing.assert_index_equal(self._fund_nav.index, self._index_price.index)
+        try:
+            # 这个指数有一天的点数是0，特殊处理一下
+            self._index_price['spi_spa'] = self._index_price['spi_spa'].where(self._index_price.spi_spa != 0).fillna(method='ffill')
+        except KeyError:
+            pass
+
+        # 对数净值取差分并且去掉第一个空值，得到基金对数收益率数列
+        self._fund_ret: pd.DataFrame = np.log(self._fund_nav).diff().iloc[1:, :]
+
+        self._fund_size = self._fund_size.reindex(self._fund_ret.index.union(self._fund_size.index)).fillna(method='ffill').reindex(self._fund_ret.index)
+        pd.testing.assert_index_equal(self._fund_ret.index, self._fund_size.index)
+
+        # 计算benchmark return，且index对齐到fund_ret
+        self._benchmark_ret: pd.DataFrame = self._get_benchmark_return()
+        self._benchmark_ret = self._benchmark_ret.reindex(self._fund_ret.index).dropna(how='all', axis=1)
+        pd.testing.assert_index_equal(self._fund_ret.index, self._benchmark_ret.index)
+        self._fund_ret = self._fund_ret.join(self._benchmark_ret, rsuffix='_b')
+        # 按wind二级分类计算基金收益率排名
+        self._get_continue_stats_tool()
+
+        self._fund_ret = self._fund_ret.join(self._hs300.rename('close_hs300'))
+        self._fund_ret = self._fund_ret.join(self._mmf.rename('close_mmf'))
+        self._fund_ret = self._fund_ret.dropna(how='all', axis=1)
+        # 获取年报/半年报的发布日期
+        md = end_date.strftime('%m%d')
+        sentry_date = pd.Series(self._REPORT_DATE_LIST)
+        sentry = sentry_date[sentry_date <= md]
+        # 为半年报/年报发布预留一个季度的缓冲时间
+        if sentry.empty:
+            real_date = datetime.date(end_date.year - 1, 6, 30)
+        elif len(sentry) <= 2:
+            real_date = datetime.date(end_date.year - 1, 12, 31)
+        else:
+            real_date = datetime.date(end_date.year, 6, 30)
+
+        # 取出持仓数据
+        self._fund_hold = self._basic_api.get_history_fund_size(start_date=real_date, end_date=real_date)
+        self._fund_hold = self._fund_hold[['fund_id', 'institution_holds', 'hold_num']].set_index('fund_id')
+        # 取出货基风险相关数据
+        self._risk_metric = self._basic_api.get_fund_hold_asset_by_id(start_date=real_date, end_date=real_date)
+        self._risk_metric = self._risk_metric[['fund_id', 'first_repo_to_nav', 'avg_ptm']].set_index('fund_id')
 
     def df_resample(self, df):
         df.index = pd.to_datetime(df.index)
@@ -138,7 +249,8 @@ class FundIndicatorProcessorGroup:
             return stutzer_index
         else:
             # result = {'information_statistic': information_statistic,
-            #         'stutzer_index': np.nan,
+            #
+            #   'stutzer_index': np.nan,
             #         'theta': result.x[0]}
             # print('未找到Information Statistic最大值')
             return np.nan
@@ -222,9 +334,8 @@ class FundIndicatorProcessorGroup:
 
     def _get_benchmark_return(self) -> pd.DataFrame:
         benchmark_list: Dict[str, float] = {}
-        fund_benchmark_df: pd.DataFrame = self._basic_api.get_fund_benchmark().drop(columns='_update_time')
         # 遍历每一只基金的benchmark进行处理
-        for row in fund_benchmark_df.itertuples(index=False):
+        for row in self._fund_benchmark_df.itertuples(index=False):
             values: List[pd.Series] = []
             cons: float = 0
             # 空的benchmark表明我们没有对应的指数或无法解析公式
@@ -243,7 +354,7 @@ class FundIndicatorProcessorGroup:
                             break
                         else:
                             try:
-                                ra: pd.Series = self._index_price.loc[:, index].copy()
+                                ra: pd.Series = self._index_price.loc[:, index]
                             except KeyError:
                                 # 表示我们没有该指数的价格数据
                                 # print(f'[benchmark_return] Error: Data Missing: {row.fund_id} {index} {index_raw}')
@@ -259,7 +370,7 @@ class FundIndicatorProcessorGroup:
                             break
                         else:
                             try:
-                                ra: pd.Series = self._index_price.loc[:, index].copy()
+                                ra: pd.Series = self._index_price.loc[:, index]
                             except KeyError:
                                 # 表示我们没有该指数的价格数据
                                 # print(f'Error: Data Missing: {row.fund_id} {index} {index_raw}')
@@ -294,10 +405,10 @@ class FundIndicatorProcessorGroup:
     def _calculate_item(self, fund_id: str, wind_2_class: str):
         # 取最后一年的有效净值
         _sr: pd.Series = self._fund_nav[fund_id]
-        sr: pd.Series = _sr[_sr.notna()].tail(self._TRADING_DAYS_PER_YEAR)
+        sr: pd.Series = _sr[_sr.notna()].tail(self._data_cycle_days)
         temp_nav = _sr.to_numpy()
-        # 生成一个18*n的矩阵
-        temp_nav = np.array([temp_nav[i*20:self._TRADING_DAYS_PER_YEAR//2+(i+1)*20] for i in range(18)])
+        # 生成一个m*n的矩阵
+        temp_nav = np.array([temp_nav[i:self._TRADING_DAYS_PER_YEAR//2 + i + 20] for i in range(0, temp_nav.shape[0] - 20 - self._TRADING_DAYS_PER_YEAR//2, 20)])
         ret: np.ndarray = temp_nav[:, 1:] / temp_nav[:, :-1]
         # 过滤掉全是nan或只有1个不是nan的行
         filter1 = (ret.shape[1] - np.count_nonzero(np.isnan(ret), axis=1) > 1)
@@ -336,17 +447,17 @@ class FundIndicatorProcessorGroup:
             continue_stats_v = np.nan
 
         # 取最后一年的有效收益率+业绩比较基准收益率
-        df_i: np.ndarray = self._fund_ret[[fund_id]].join(self._benchmark_ret[fund_id], rsuffix='_b').to_numpy()
+        df_i: np.ndarray = self._fund_ret[[fund_id, fund_id+'_b']].to_numpy()
         df_i = df_i[(~np.isnan(df_i)).all(axis=1)]
-        df_i = df_i[-self._TRADING_DAYS_PER_YEAR:]
+        df_i = df_i[-self._data_cycle_days:]
 
-        df_i_hs300: np.ndarray = self._fund_ret[[fund_id]].join(self._hs300, rsuffix='_b').to_numpy()
+        df_i_hs300: np.ndarray = self._fund_ret[[fund_id, 'close_hs300']].to_numpy()
         df_i_hs300 = df_i_hs300[(~np.isnan(df_i_hs300)).all(axis=1)]
-        df_i_hs300 = df_i_hs300[-self._TRADING_DAYS_PER_YEAR:]
+        df_i_hs300 = df_i_hs300[-self._data_cycle_days:]
 
-        df_i_mmf: np.ndarray = self._fund_ret[[fund_id]].join(self._mmf, rsuffix='_b').to_numpy()
+        df_i_mmf: np.ndarray = self._fund_ret[[fund_id, 'close_mmf']].to_numpy()
         df_i_mmf = df_i_mmf[(~np.isnan(df_i_mmf)).all(axis=1)]
-        df_i_mmf = df_i_mmf[-self._TRADING_DAYS_PER_YEAR:]
+        df_i_mmf = df_i_mmf[-self._data_cycle_days:]
 
         # alpha, beta
         alpha, beta = self._lambda_alpha_beta(df_i)
@@ -376,7 +487,7 @@ class FundIndicatorProcessorGroup:
         # excess return against mmf
         _ex_return_mmf = df_i_mmf[:, 0] - df_i_mmf[:, 1]
         # winning rate against mmf
-        winning_rate = len(_ex_return_mmf[_ex_return_mmf>0])/len(_ex_return_mmf)
+        winning_rate = len(_ex_return_mmf[_ex_return_mmf > 0]) / len(_ex_return_mmf)
         # track error
         track_err = np.nanstd(_ex_return, ddof=1) * np.sqrt(self._TRADING_DAYS_PER_YEAR)
         # track error agains hs300
@@ -389,22 +500,26 @@ class FundIndicatorProcessorGroup:
         scale = self.get_scale(self.end_date, fund_id)
         # VaR
         ret = df_i[:, 0]
-        VaR = np.quantile(ret, 0.05)
-        CVaR = ret[ret <= VaR].mean()
-        # institution holds & hold_num
-        if fund_id in self._fund_hold.fund_id.values:
-            temp_hold = self._fund_hold[self._fund_hold.fund_id == fund_id]
-            ins_holds = temp_hold.institution_holds.values[0]
-            hold_num = temp_hold.hold_num.values[0]
+        if ret.size > 0:
+            VaR = np.quantile(ret, 0.05)
+            CVaR = ret[ret <= VaR].mean()
         else:
+            VaR = np.nan
+            CVaR = np.nan
+        # institution holds & hold_num
+        try:
+            temp_hold = self._fund_hold.loc[fund_id, :]
+            ins_holds = temp_hold.institution_holds
+            hold_num = temp_hold.hold_num
+        except KeyError:
             ins_holds = np.nan
             hold_num = np.nan
         #
-        if fund_id in self._risk_metric.fund_id.values:
-            temp_risk = self._risk_metric[self._risk_metric.fund_id == fund_id]
-            leverage = temp_risk.first_repo_to_nav.values[0]
-            ptm = temp_risk.avg_ptm.values[0]
-        else:
+        try:
+            temp_risk = self._risk_metric.loc[fund_id, :]
+            leverage = temp_risk.first_repo_to_nav
+            ptm = temp_risk.avg_ptm
+        except KeyError:
             leverage = np.nan
             ptm = np.nan
 
@@ -489,24 +604,45 @@ class FundIndicatorProcessorGroup:
         fund_list = self._fund_list[['fund_id', 'wind_class_2']]
         # 对fund_nav, benchmark_ret, fund_list三者交集的每个fund_id进行计算
         self._result = fund_list[fund_list.fund_id.isin(self._fund_nav.columns.intersection(self._benchmark_ret.columns).to_list())].apply(lambda x: self._calculate_item(x.fund_id, x.wind_class_2), axis=1)
+        self._result['data_cycle'] = str(self._data_cycle) + 'Y'
 
     def process(self, start_date: str, end_date: str, end_date_dt: datetime.date) -> List[str]:
         print(f'indicator group update on the last day of week {end_date_dt}')
         failed_tasks: List[str] = []
         try:
-            self.init(start_date, end_date)
+            self.init(end_date)
             print('init done, to calc indicators')
             self.calculate()
-            # self._result.to_csv('result.csv')
             self._data_helper._upload_derived(self._result, FundIndicatorGroup.__table__.name)
         except Exception as e:
             print(e)
             traceback.print_exc()
-            failed_tasks.append('fund_indicator_group')
+            failed_tasks.append(f'fund_indicator_group({self._data_cycle}Y)')
         return failed_tasks
 
+    @staticmethod
+    def update_history(end_date: str, data_cycle: int):
+        from ...wrapper.mysql import BasicDatabaseConnector
+        from ...view.basic_models import TradingDayList
+        with BasicDatabaseConnector().managed_session() as quant_session:
+            query = quant_session.query(TradingDayList)
+            trade_days = pd.read_sql(query.statement, query.session.bind)
+
+        fipg = FundIndicatorProcessorGroup(DerivedDataHelper(), data_cycle)
+        fipg.history_load_data(end_date)
+        dts = trade_days[(trade_days.datetime >= datetime.date(2010, 1, 1)) &
+                         (trade_days.datetime < pd.to_datetime(end_date, infer_datetime_format=True))].datetime.tolist()
+        dts.reverse()
+        dts = [dt for dt in dts if dt.weekday() == 4]
+        for date in dts:
+            fipg.history_init(date)
+            fipg.calculate()
+            fipg._data_helper._upload_derived(fipg._result, FundIndicatorGroup.__table__.name)
+            print(f'{date} done')
+
 
 if __name__ == '__main__':
-    date = '20200904'
-    fsg = FundIndicatorProcessorGroup(DerivedDataHelper())
-    fsg.process(date, date, pd.to_datetime(date).date())
+    date = '20200930'
+    fipg = FundIndicatorProcessorGroup(DerivedDataHelper(), 5)
+    fipg.process(date, date, pd.to_datetime(date).date())
+    # FundIndicatorProcessorGroup.update_history('20201009', 5)
