@@ -6,6 +6,7 @@ import traceback
 from functools import partial
 from sklearn.metrics import r2_score
 import concurrent.futures
+from multiprocessing import Pool
 from ...manager.manager_fund import FundDataManager
 from ...manager.score import FundScoreManager
 from ...wrapper.mysql import DerivedDatabaseConnector
@@ -190,7 +191,7 @@ class FundIndicatorProcessor(object):
             'year_length':year_length}
         return dic
 
-    def _process_fund_indicator_one(self, fund_id, time_range, fund_ret, index_id, index_ret):
+    def _process_fund_indicator_one(self, time_range, fund_ret, index_id, index_ret, fund_id):
         df = fund_ret[[fund_id]].join(index_ret).dropna()
         df = df.rename(columns={index_id:'benchmark',fund_id:'fund'}).reset_index()
         df['year_length'] = df['datetime'].map(lambda x: (x-self.start_date_dic[fund_id]).days / self.NATURAL_DAYS_PER_YEAR)
@@ -237,20 +238,14 @@ class FundIndicatorProcessor(object):
             time_range = self.get_time_range(index_id)
             fund_list_1 = self.index_fund[index_id]
             fund_list_2 = self._dm.dts.active_fund_info[self._dm.dts.active_fund_info['index_id'] == index_id].fund_id.tolist()
-            fund_list = list(set(fund_list_1).union(set(fund_list_2)))
+            fund_list = list(set(fund_list_1).union(set(fund_list_2)).intersection(self._dm.dts.all_fund_list))
             fund_ret = self.fund_ret[fund_list].copy()
             index_ret = self.index_ret[[index_id]]
-            with concurrent.futures.ProcessPoolExecutor(max_workers=cpu_num) as executor:
-                future_to_bti = {executor.submit(self._process_fund_indicator_one, fund_id, time_range, fund_ret, index_id, index_ret): fund_id for fund_id in fund_list}
-                for future in concurrent.futures.as_completed(future_to_bti):
-                    bt_i = future_to_bti[future]
-                    try:
-                        data = future.result()
-                        result.append(data)
-                    except Exception as exc:
-                        print(f'{bt_i} generated an exception: {exc}')
-                    else:
-                        pass
+            p = Pool()
+            res = [i for i in p.imap_unordered(partial(self._process_fund_indicator_one, time_range, fund_ret, index_id, index_ret), fund_list, 256) if i is not None]
+            p.close()
+            p.join()
+            result.extend(res)    
             print(f'index {index_id} fund number : {len(fund_list)} finish' )
         result = [ _ for _ in result if not _ is None]
         self.result = pd.concat(result, axis=0, sort=True)
@@ -263,7 +258,7 @@ class FundIndicatorProcessor(object):
             time_range = self.get_time_range(index_id)
             fund_list_1 = self.index_fund[index_id]
             fund_list_2 = self._dm.dts.active_fund_info[self._dm.dts.active_fund_info['index_id'] == index_id].fund_id.tolist()
-            fund_list = list(set(fund_list_1).union(set(fund_list_2)))
+            fund_list = list(set(fund_list_1).union(set(fund_list_2)).intersection(self._dm.dts.all_fund_list))
             fund_ret = self.fund_ret[fund_list].copy()
             index_ret = self.index_ret[[index_id]]
             for fund_id in fund_list:
