@@ -20,6 +20,7 @@ class FundDailyCollectionProcessor(object):
                     FundInfo.wind_class_1,
                     FundInfo.wind_class_2,
                     FundInfo.start_date,
+                    FundInfo.end_date,
                     # FundInfo.manager_id,
                     FundInfo.fund_manager,
                     FundInfo.company_id,
@@ -257,7 +258,7 @@ class FundDailyCollectionProcessor(object):
                 subq = mn_session.query(
                     FundScoreNew.fund_id.label('temp_id'),
                     func.max(FundScoreNew.datetime).label('temp_date'),
-                ).group_by(FundScoreNew.fund_id).subquery()
+                ).filter(FundScoreNew.data_cycle == '1Y').group_by(FundScoreNew.fund_id).subquery()
 
                 query = mn_session.query(
                     FundScoreNew.fund_id,
@@ -270,7 +271,8 @@ class FundDailyCollectionProcessor(object):
                     FundScoreNew.total_score,
                 ).filter(
                     FundScoreNew.fund_id == subq.c.temp_id,
-                    FundScoreNew.datetime == subq.c.temp_date
+                    FundScoreNew.datetime == subq.c.temp_date,
+                    FundScoreNew.data_cycle == '1Y',
                 )
 
                 df = pd.read_sql(query.statement, query.session.bind)
