@@ -12,7 +12,8 @@ from ...constant import SectorType, IndexPriceSource
 from ...util.config import SurfingConfigurator, AWSSettings
 from ..wrapper.mysql import RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector
 from ..view.raw_models import CSIndexComponent
-from ..view.basic_models import FundInfo, TradingDayList, IndexInfo, IndexPrice, FundNav, Fund_size_and_hold_rate, FundBenchmark
+from ..view.basic_models import FundInfo, TradingDayList, IndexInfo, IndexPrice, FundNav, Fund_size_and_hold_rate, FundBenchmark, FundIPOStats
+from ..view.basic_models import FundConvStats
 from ..view.derived_models import FundIndicator, FundIndicatorAnnual, IndexValuationLongTerm, FundIndicatorWeekly
 from ..view.derived_models import FundIndicatorMonthly, BarraCNE5FactorReturn, FundManagerScore, FundManagerInfo, FundManagerFundRank
 from .data_tables import FundDataTables
@@ -67,6 +68,8 @@ class SynchronizerS3ForDM(S3ETLTool):
         FundNav,
         Fund_size_and_hold_rate,
         FundBenchmark,
+        FundIPOStats,
+        FundConvStats,
     ]
     # DM中需要使用的derived table
     _DERIVED_TABLE_LIST = [
@@ -360,7 +363,7 @@ class S3RetrieverForDM(S3ETLTool):
             try:
                 # 把我们保存的df转换回原来的类型
                 df = pd.read_parquet(f'{self._s3_bucket_uri}/_ndf_{name}.parquet')
-                if name in ('fund_list','all_fund_list', 'index_list', 'index_date_list'):
+                if name in ('fund_list', 'all_fund_list', 'fund_ipo_list', 'fund_conv_list', 'index_list', 'index_date_list'):
                     data = set(df.to_dict(orient='list')[name])
                     if name == 'index_date_list':
                         data = sorted(data)
