@@ -198,4 +198,16 @@ def active_fund_info(fund_info: pd.DataFrame, fund_benchmark: pd.DataFrame):
     # 只选择成立一年的
     _begin_date = datetime.datetime.today().date() - datetime.timedelta(days=365)
     active_fund_info = active_fund_info[active_fund_info['start_date'] < _begin_date]
-    return active_fund_info
\ No newline at end of file
+    return active_fund_info
+
+def get_ipos_funds(ipo_weight_df):
+    # 过去一年如果打新金额占比大于0.15， 作为打新型基金
+    ipo_weight_df = ipo_weight_df.pivot_table(index='end_date', columns='fund_id', values='ipo_allocation_weight').fillna(0)
+    ipo_weight_last_year_df = ipo_weight_df + ipo_weight_df.shift(1).fillna(0) + ipo_weight_df.shift(2).fillna(0) + ipo_weight_df.shift(3).fillna(0)
+    ipo_funds = ipo_weight_last_year_df.columns[ipo_weight_last_year_df.max() > 0.15].values.tolist()
+    return ipo_funds
+
+def get_conv_funds(fund_conv_stats):
+    conv_df = fund_conv_stats.pivot_table(index='datetime', values='conv_weights', columns='fund_id')
+    conv_funds = conv_df.columns[conv_df.max() > 20].tolist()
+    return conv_funds
\ No newline at end of file
