@@ -11,7 +11,7 @@ import json
 import contextlib
 import re
 from ..wrapper.mysql import RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector
-from .fund_info_filter import filter_fund_info, fund_info_update, active_fund_info
+from .fund_info_filter import filter_fund_info, fund_info_update, active_fund_info, get_ipos_funds, get_conv_funds
 from ..struct import AssetPrice, FundScoreParam, TaaTunerParam, AssetTimeSpan
 from .score import FundScoreManager, ScoreFunc
 from .data_tables import FundDataTables
@@ -44,6 +44,8 @@ def profiled(file_name=None):
 
 class FundDataManager(DataManager):
 
+    _BLOCK_DF_LIST = ('fund_manager_score', 'fund_indicator')
+
     def __init__(self, start_time=None, end_time=None, fund_score_param: FundScoreParam = None, score_manager: FundScoreManager = None, s3_retriever_activation: bool = False):
         DataManager.__init__(self,
             start_time or datetime.datetime(2005, 1, 1),
@@ -93,7 +95,7 @@ class FundDataManager(DataManager):
         print('init from s3 with all default config done')
 
     # 使用默认配置的DM+自定义的FundScoreManager
-    def _init_from_s3_with_score_customized(self, score_pre_calc=True, use_weekly_monthly_indicators=False):
+    def _init_from_s3_with_score_customized(self, score_pre_calc, use_weekly_monthly_indicators):
         print('try to init from s3 with score customized')
 
         # 初始化取得默认配置的DM
@@ -110,7 +112,7 @@ class FundDataManager(DataManager):
         self._is_inited = True
         print(f'init from s3 with score customized done, score pre calculation costs {_t1 - _t0}')
 
-    def try_to_init_from_s3(self, default_value_flag: List[bool], score_pre_calc, use_weekly_monthly_indicators) -> bool:
+    def try_to_init_from_s3(self, default_value_flag: List[bool], score_pre_calc, use_weekly_monthly_indicators, block_df_list) -> bool:
         # 判断init中的参数是否都是与默认值相同的值
         if not all(default_value_flag):
             return False
@@ -126,9 +128,11 @@ class FundDataManager(DataManager):
             print('init failed from s3')
             return False
 
+        # 干掉不用的字段以节省内存
+        self.dts.remove_fields(block_df_list)
         return True
 
-    def init(self, index_list=None, score_pre_calc=True, print_time=False, use_weekly_monthly_indicators=False):
+    def init(self, index_list=None, score_pre_calc=True, print_time=False, use_weekly_monthly_indicators=False, block_df_list=_BLOCK_DF_LIST):
         if self._s3_retriever.is_activated:
             # Caution!! 这里应始终保持init传进来的参数与try_to_init_from_s3第一个参数相适应，以正确判断是否为默认配置
             # 如果init中的参数改成keyword类型，可以使用__kwdefaults__来帮助判断
@@ -137,7 +141,7 @@ class FundDataManager(DataManager):
                                         self.end_date == std_dm.end_date,
                                         index_list is None or not index_list,
                                         use_weekly_monthly_indicators is False,
-                                        ], score_pre_calc, use_weekly_monthly_indicators):
+                                        ], score_pre_calc, use_weekly_monthly_indicators, block_df_list):
                 # 从s3成功读取数据，直接返回
                 return
         print('could not init from s3 directly, do normal initialization')
@@ -253,10 +257,22 @@ class FundDataManager(DataManager):
             self.dts.active_fund_info = active_fund_info(self.dts.fund_info, self.dts.fund_benchmark_info)
             _tm_basic_fetch_info = time.time()
             self.dts.fund_info = fund_info_update(self.dts.fund_info)
+            self.dts.fund_status_latest = fetch_table(quant_session, FundStatusLatest)
+            _fund_open_info = fetch_table(quant_session, FundOpenInfo)
             _filter_fund_info = filter_fund_info(self.dts.fund_info, index_list)
             _tm_basic_filter_info = time.time()
             self.dts.fund_list = set(_filter_fund_info.fund_id)
             self.dts.all_fund_list = self.dts.fund_list.union(self.dts.active_fund_info.fund_id)
+            in_market_fund_list = self.dts.fund_status_latest[~self.dts.fund_status_latest['trade_status'].isnull()].fund_id.tolist()
+            close_fund_list = _fund_open_info.fund_id.tolist()
+            self.dts.fund_ipo_stats = fetch_table(quant_session, FundIPOStats)
+            self.dts.fund_conv_stats = fetch_table(quant_session, FundConvStats)
+            self.dts.fund_ipo_list = get_ipos_funds(self.dts.fund_ipo_stats)
+            self.dts.fund_conv_list = get_conv_funds(self.dts.fund_conv_stats)
+            self.dts.fund_ipo_list = {i for i in self.dts.fund_ipo_list if (i not in in_market_fund_list) and (i not in close_fund_list)}
+            self.dts.fund_conv_list = {i for i in self.dts.fund_conv_list if (i not in in_market_fund_list) and (i not in close_fund_list)}
+            self.dts.all_fund_list = {i for i in self.dts.all_fund_list if (i not in in_market_fund_list) and (i not in close_fund_list)}
+            self.dts.all_fund_list = self.dts.all_fund_list.union(self.dts.fund_ipo_list).union(self.dts.fund_conv_list)
             _normal_funds_index_dic = {cur.fund_id: cur.index_id for cur in _filter_fund_info.itertuples()}
             _active_funds_index_dic = {i.fund_id: i.index_id for i in self.dts.active_fund_info.itertuples()}
             self.dts.fund_index_map = {**_normal_funds_index_dic, **_active_funds_index_dic}
@@ -316,7 +332,6 @@ class FundDataManager(DataManager):
             self.dts.fund_size = _temp_size_and_hold_rate['size']
             self.dts.fund_com_hold = _temp_size_and_hold_rate['institution_holds']
             _tm_basic_fetch_fund_size = time.time()
-
             if print_time:
                 print(f'\t[time][basic] fetch fund info : {_tm_basic_fetch_info - _tm_basic_start}')
                 print(f'\t[time][basic] filter fund info: {_tm_basic_filter_info - _tm_basic_fetch_info}')
@@ -504,6 +519,10 @@ class FundDataManager(DataManager):
         if score_pre_calc:
             self._score_manager.pre_calculate(is_filter_c=True, use_weekly_monthly_indicators=use_weekly_monthly_indicators)
             self._score_manager.pre_calculate_manager()
+
+        # 干掉不用的字段以节省内存
+        self.dts.remove_fields(block_df_list)
+
         _tm_finish = time.time()
         print(self.dts)
         if print_time:
@@ -676,7 +695,7 @@ class FundDataManager(DataManager):
 
     def find_same_size_type_funds(self, desc_name):
         fund_info = self.dts.fund_info.copy()
-        fund_info['trim_name'] = fund_info.desc_name.map(lambda x : re.subn(r'[ABCDEFR]{1,2}(\(人民币\)|\(美元现汇\)|\(美元现钞\)|1|2|3)?$', '', x))
+        fund_info['trim_name'] = fund_info.desc_name.map(lambda x : re.subn(r'[ABCDEFR]{1,2}(\(人民币\)|\(美元现汇\)|\(美元现钞\)|1|2|3)?$', '', x)[0])
         fund_info = fund_info.set_index(['trim_name','desc_name'])
         index_1 = fund_info.loc[pd.IndexSlice[:, desc_name], :].index.get_level_values(0).values[0]
         return fund_info.loc[index_1]
