@@ -12,6 +12,38 @@ import math
 import numpy as np
 from copy import deepcopy
 
+
+@dataclasses.dataclass
+class ManagerFunc:
+    trade_year: float = 0
+    annualized_ret: float = 0
+    annualized_vol: float = 0
+    model_alpha: float = 0
+    model_beta: float = 0
+    sharpe: float = 0
+
+    def get(self, data):
+        return  self.trade_year * data.trade_year \
+                + self.annualized_ret * data.annualized_ret \
+                + self.annualized_vol * data.annualized_vol \
+                + self.model_beta * data.model_beta \
+                + self.model_alpha * data.model_alpha \
+                + self.sharpe * data.sharpe
+
+    def __str__(self):
+        func_str = ''
+        for fac, w in self.__dict__.items():
+            if w == 0:
+                continue
+            flag = ''
+            if w > 0:
+                flag = '+'
+            if fac == 'beta':
+                func_str += f'{flag}{w} * abs(1-{fac})'
+            else:
+                func_str += f'{flag}{w} * {fac}'
+        return func_str
+
 @dataclasses.dataclass
 class ScoreFunc:
 
@@ -19,12 +51,19 @@ class ScoreFunc:
     beta: float = 0  # weight of abs(1-beta), or beta's deviation from 1
     track_err: float = 0  # weight of track_err
     fee_rate: float = 0  # weight of fee_rate
+    info_ratio: float = 0
+    mng_annualized_ret: float = 0
+    mng_annualized_vol: float = 0
+    mng_model_alpha: float = 0
+    mng_model_beta: float = 0
+    mng_sharpe: float = 0
+    mng_trade_year: float = 0
+    active: float = -10 #默认条件不选择主动型，对主动性加分数惩罚
     # last_year_alpha: float = 0
     # last_year_beta: float = 0
     # last_two_year_alpha: float = 0
     # last_two_year_beta: float = 0
     # down_risk: float = 0
-    # info_ratio: float = 0
     # ret_over_period: float = 0
     # treynor: float = 0
     # mdd: float = 0
@@ -48,7 +87,15 @@ class ScoreFunc:
         return  self.alpha * data.alpha \
                 + self.track_err * data.track_err \
                 + self.fee_rate * data.fee_rate \
-                + self.beta * abs(1-data.beta)
+                + self.beta * abs(1-data.beta) \
+                + self.info_ratio * data.info_ratio \
+                + data.mng_annualized_ret.mul(other=self.mng_annualized_ret, fill_value=0) \
+                + data.mng_annualized_vol.mul(other=self.mng_annualized_vol, fill_value=0) \
+                + data.mng_model_alpha.mul(other=self.mng_model_alpha, fill_value=0) \
+                + data.mng_model_beta.mul(other=self.mng_model_beta, fill_value=0) \
+                + data.mng_sharpe.mul(other=self.mng_sharpe, fill_value=0) \
+                + data.mng_trade_year.mul(other=self.mng_trade_year, fill_value=0) \
+                + data.active * self.active
                 # + self.down_risk * data.down_risk \
                 # + self.info_ratio * data.info_ratio \
                 # + self.ret_over_period * data.ret_over_period \
@@ -112,21 +159,62 @@ class FundScoreManager:
         self.params = None
         self.dts = None
         self.funcs = {
-            'hs300': ScoreFunc(alpha=0.6, beta=-0.3),
-            'csi500': ScoreFunc(alpha=0.9, beta=-0.1),
-            'gem':ScoreFunc(alpha=0.3, beta=-0.50, track_err=-0.2),
-            'national_debt': ScoreFunc(alpha=0.20, beta=-0.45, track_err=-0.35),
-            'mmf': ScoreFunc(alpha=0.3, beta=-0.2, fee_rate=-0.1, track_err=-0.4),
-            'sp500rmb': ScoreFunc(fee_rate=-0.2, track_err=-0.8),
-            'gold': ScoreFunc(alpha=0.15, track_err=-0.85),
-            'hsi': ScoreFunc(alpha=0.3, fee_rate=-0.3, track_err=-0.4),# set default score equation
+            'hs300': {
+                'default': ScoreFunc(track_err=-0.4,beta=-0.6),
+                'enhanced':ScoreFunc(alpha=0.6, beta=-0.3),
+                'active': ScoreFunc(mng_trade_year=0.15, mng_annualized_ret=0.15, mng_sharpe=0.15,alpha=0.1,mng_model_alpha=0.3,mng_model_beta=0.15,active=10),    
+            },
+            'csi500': {
+                'default': ScoreFunc(info_ratio=0.2,track_err=-0.7, fee_rate=-0.1),
+                'enhanced':ScoreFunc(alpha=0.9, beta=-0.1),
+                'active': ScoreFunc(mng_trade_year=0.15, mng_annualized_ret=0.15, mng_sharpe=0.15,alpha=0.1,mng_model_alpha=0.3,mng_model_beta=0.15,active=10),
+            }, 
+            'gem': {
+                'default': ScoreFunc(info_ratio=0.2,track_err=-0.7, fee_rate=-0.1),
+                'enhanced':ScoreFunc(alpha=0.3, beta=-0.50, track_err=-0.2),
+                'active': ScoreFunc(mng_trade_year=0.15, mng_annualized_ret=0.15, mng_sharpe=0.15,alpha=0.1,mng_model_alpha=0.3,mng_model_beta=0.15,active=10),  
+            },
+            'national_debt': {
+                'default':ScoreFunc(alpha=0.20, beta=-0.45, track_err=-0.35),
+            }, 
+            'mmf':{
+                'default':ScoreFunc(alpha=0.3, beta=-0.2, fee_rate=-0.1, track_err=-0.4),
+            }, 
+            'sp500rmb':{
+                'default':ScoreFunc(fee_rate=-0.2, track_err=-0.8)
+            },  
+            'gold': {
+                'default':ScoreFunc(alpha=0.15, track_err=-0.85),
+            },  
+            'hsi': {
+                'default':ScoreFunc(alpha=0.3, fee_rate=-0.3, track_err=-0.4),# set default score equation
+            },  
+            'active': {
+                'default':ManagerFunc(trade_year=0.15, annualized_ret=0.15, sharpe=0.15, model_alpha=0.3, model_beta=0.15)
+            },
         }
         self.score_cache = defaultdict(dict)
         self.score_raw_cache = defaultdict(dict)
+        self.score_manager_cache = defaultdict(dict)
         self.score_filter = score_filter
         self.score_penalty_param = score_penalty_param
         self._size_and_com_hold_cache: Dict[Any, pd.Index] = {}
 
+    # Caution!!增加字段应考虑相应修改该函数
+    def __eq__(self, other):
+        if not isinstance(other, type(self)):
+            return NotImplemented
+
+        if self.params != other.params:
+            return False
+        if self.funcs != other.funcs:
+            return False
+        if self.score_filter != other.score_filter:
+            return False
+        if self.score_penalty_param != other.score_penalty_param:
+            return False
+        return True
+
     # 获取字符串形式的各大类的默认score func
     def get_default_func_str(self) -> Dict[str, str]:
         return {index_id: str(score_func) for index_id, score_func in self.funcs.items()}
@@ -184,6 +272,25 @@ class FundScoreManager:
         score_raw.update({index_id: v for index_id, v in index_score_raw.items() if index_id not in score_raw})
         return score, score_raw
 
+    def get_manager_scores(self, dt, active_fund_id_list, score_select):
+        index_id = 'active'
+        type_i = score_select[index_id]
+        fund_ids = self._filter_size_and_com_hold(dt, index_id, active_fund_id_list)
+        manager_score = self.score_manager_cache[dt][score_select[index_id]].to_dict()
+        try:
+            _manager_funds = self.dts.fund_manager_rank.loc[dt].to_dict()['fund_list']
+            # 根据对规模和持有人结构筛选条件过滤基金
+            manager_funds = {}
+            for mng_id, mng_funds in _manager_funds.items():
+                _mng_funds = [ i for i in mng_funds if i in fund_ids]
+                if len(_mng_funds) > 0:
+                    manager_funds[mng_id] = _mng_funds[0] 
+            # 如果经理当时不存基金, 即无基金可选, 直接去掉分数
+            manager_score = {mng_id : score_i for mng_id, score_i in manager_score.items() if mng_id in manager_funds}
+            return {type_i:manager_score}, manager_funds
+        except:
+            return {type_i:{}}, {}
+
     def _wrapper(self, df: pd.DataFrame, is_filter_c: bool, use_weekly_monthly_indicators: bool):
         # T日大类下有很多基金，这里取一下它们的datetime和index_id，因为值都是一样的所以取array[0]就OK
         dt = df.datetime.array[0]
@@ -193,53 +300,75 @@ class FundScoreManager:
         self.score_cache[dt][index_id] = score
         self.score_raw_cache[dt][index_id] = score_raw
 
+    def _wrapper_manager(self, df: pd.DataFrame):
+        dt = df.datetime.array[0]
+        manager_rank = self._get_manager_score(dt=dt, cur_d=df.set_index('manager_id').drop(columns=['datetime']))
+        self.score_manager_cache[dt] = manager_rank
+
     def pre_calculate(self, is_filter_c=True, use_weekly_monthly_indicators=False):
         # self.dts.fund_indicator.pivot_table(index=['datetime', 'index_id'])
         # 上面这一行会耗时10秒左右，且之后遍历index(datetime-index_id pair)也会比下边groupby慢一些
         # 这里应该没必要先groupby datetime，再groupby index_id（如果真这样可能更慢吧）
         self.dts.fund_indicator.groupby(by=['datetime', 'index_id']).apply(lambda x: self._wrapper(x, is_filter_c, use_weekly_monthly_indicators))
-        
+
+    def pre_calculate_manager(self):
+        self.dts.fund_manager_score.groupby(by=['datetime']).apply(lambda x: self._wrapper_manager(x))
+
+    def _get_manager_score(self, dt, cur_d):
+        # manager top list first
+        index_id = 'active'
+        cur_d = cur_d.apply(lambda x: (x - x.mean() + 1e-6)/ (x.std() + 1e-6), axis=0)
+        func_dic = self.funcs.get(index_id)
+        score_sum = {}
+        for type_i, func in func_dic.items():
+            score = func.get(cur_d)
+            score_sum[type_i] = score
+        return score_sum
+
     def _get_score(self, index_id, dt, cur_d, is_filter_c, use_weekly_monthly_indicators=False, score_func: Optional[Union[ScoreFunc, str]] = None):
         fund_ids = self._filter_size_and_com_hold(dt, index_id, cur_d.index)
         if fund_ids is not cur_d.index:
             # 这里没有dropna总计可以快24秒
             cur_d = cur_d.reindex(fund_ids)
+        func_dic = self.funcs.get(index_id) if score_func is None else {'temp': score_func}
         if cur_d.shape[0] > 1:
             cur_d_sta = cur_d.apply(lambda x: (x - x.mean() + 1e-6)/ (x.std() + 1e-6), axis=0)
             cur_d_sta['beta'] = cur_d['beta']
             cur_d_sta['year_length'] = cur_d['year_length']
             cur_d = cur_d_sta
-            func = self.funcs.get(index_id) if score_func is None else score_func
-            if isinstance(func, str):
-                try:
-                    FundScoreManager.test_func(func)
-                except Exception as e:
-                    # func str不合法，直接返回空
-                    print(f'eval fund score func str failed for {index_id} (err_msg){e}')
-                    return {}, {}
-                score_raw = cur_d.apply(FundScoreManager.get_func(func), axis=1)
-            else:
-                # 默认均走这个分支
-                if use_weekly_monthly_indicators:
-                    score_raw = cur_d.apply(lambda x: func.get_all(x), axis=1)
+            score_raw_sum = {}
+            score_sum = {}
+            for type_i, func in func_dic.items():
+                if isinstance(func, str):
+                    try:
+                        FundScoreManager.test_func(func)
+                    except Exception as e:
+                        # func str不合法，直接返回空
+                        print(f'eval fund score func str failed for {index_id} (err_msg){e}')
+                        return {}, {}
+                    score_raw = cur_d.apply(FundScoreManager.get_func(func), axis=1)
                 else:
-                    score_raw = cur_d.apply(lambda x: func.get(x), axis=1)
-            if index_id in self.score_penalty_param.FilterYearIndex:
-                punish_funds = cur_d[cur_d.year_length < self.score_penalty_param.JudgeYearLength].index.tolist()
-                for _fund_id in punish_funds:
-                    score_raw[_fund_id] += self.score_penalty_param.Penalty
-                # 以下是vectorize calc, 但看起来没有明显的加速效果
-                # punish_funds = pd.Series(self.score_penalty_param.Penalty, index=cur_d[cur_d.year_length < self.score_penalty_param.JudgeYearLength].index)
-                # score_raw = score_raw.add(punish_funds, fill_value=0)
-            score = (score_raw - score_raw.min()) / (score_raw.max() - score_raw.min())
-            if is_filter_c:
-                score = self._filter_score(score)
-            score = score.to_dict()
-            score_raw = score_raw.to_dict()
+                    # 默认均走这个分支
+                    if use_weekly_monthly_indicators:
+                        score_raw = func.get_all(cur_d)
+                    else:
+                        score_raw = func.get(cur_d)
+                if index_id in self.score_penalty_param.FilterYearIndex:
+                    punish_funds = cur_d[cur_d.year_length < self.score_penalty_param.JudgeYearLength].index.tolist()
+                    for _fund_id in punish_funds:
+                        score_raw[_fund_id] += self.score_penalty_param.Penalty
+                    # 以下是vectorize calc, 但看起来没有明显的加速效果
+                    # punish_funds = pd.Series(self.score_penalty_param.Penalty, index=cur_d[cur_d.year_length < self.score_penalty_param.JudgeYearLength].index)
+                    # score_raw = score_raw.add(punish_funds, fill_value=0)
+                score = (score_raw - score_raw.min()) / (score_raw.max() - score_raw.min())
+                if is_filter_c:
+                    score = self._filter_score(score)
+                score_sum[type_i] = score.to_dict()
+                score_raw_sum[type_i] = score_raw.to_dict()
         else:
-            score_raw = {cur_d.index[0]: 1}
-            score = score_raw
-        return score, score_raw
+            score_raw_sum = {type_i : {cur_d.index[0]: 1} for type_i in func_dic}
+            score_sum = score_raw_sum
+        return score_sum, score_raw_sum
 
     def _filter_size_and_com_hold(self, dt, index_id: str, fund_ids: pd.Index):
         if index_id not in self.score_filter.FilterIndexId:
@@ -298,14 +427,15 @@ class FundScoreManager:
     def _white_black_func(self, score, disproved_set):
         del_list = []
         for index_id in score:
-            for fund_id in score[index_id]:
-                if fund_id in disproved_set:
-                    # 之前是给非白名单 黑名单的基金给分数惩罚，但是基金数量不足时，会交易
-                    # 现在改为强逻辑，直接删掉
-                    #score[index_id][fund_id] += self.score_penalty_param.BlackListPenalty
-                    del_list.append([index_id, fund_id])
+            for type_i in score[index_id]:
+                for fund_id in score[index_id][type_i]:
+                        if fund_id in disproved_set:
+                            # 之前是给非白名单 黑名单的基金给分数惩罚，但是基金数量不足时，会交易
+                            # 现在改为强逻辑，直接删掉
+                            #score[index_id][fund_id] += self.score_penalty_param.BlackListPenalty
+                            del_list.append([index_id, type_i, fund_id])
         for del_i in del_list:
-            del score[del_i[0]][del_i[1]]
+            del score[del_i[0]][del_i[1]][del_i[2]]
         return score
 
     @staticmethod
