@@ -190,6 +190,8 @@ class FundPosItem:
             self.avg_cost = amt / volume
         else:
             self.volume -= trade.volume
+            if trade.is_to_cleanup:
+                self.volume = 0
             if self.volume < 1e-8:# 清空仓位 平均成本为0
                 self.avg_cost = 0
             else: #非清仓卖出 平均成本不变
