@@ -350,6 +350,10 @@ class Fund_size_and_hold_rate(Base):
     institution_holds = Column(DOUBLE(asdecimal=False)) # 机构持有比例 单位百分比
     hold_num = Column(DOUBLE(asdecimal=False))  # 基金份额持有人户数
 
+    __table_args__ = (
+        Index('idx_fund_size_and_hold_rate_datetime', 'datetime'),
+    )
+
 class FundRate(Base):
     '''基金评级'''
 
@@ -394,6 +398,10 @@ class FundHoldAsset(Base):
     first_repo_to_nav = Column(DOUBLE(asdecimal=False))  # 报告期内债券回购融资余额占基金资产净值比例
     avg_ptm = Column(DOUBLE(asdecimal=False))  # 报告期末投资组合平均剩余期限
 
+    __table_args__ = (
+        Index('idx_fund_hold_asset_datetime', 'datetime'),
+    )
+
 class FundHoldIndustry(Base):
     '''基金持仓前三行业'''
 
@@ -607,6 +615,8 @@ class FundIPOStats(Base):
     ipo_allocation_amount = Column(DOUBLE(asdecimal=False)) # 累计获配金额(万元)
     ipo_allocation_ret = Column(DOUBLE(asdecimal=False)) # 打新收益率(%)
     start_date = Column(DATE)  # 开始统计日期
+    size = Column(DOUBLE(asdecimal=False)) # 基金规模
+    ipo_allocation_weight = Column(DOUBLE(asdecimal=False)) # 基金打新比例
 
 class FundConvStats(Base):
     '''基金可转债比例'''
@@ -617,3 +627,10 @@ class FundConvStats(Base):
     datetime = Column(DATE, primary_key=True) # 日期
     conv_weights = Column(DOUBLE(asdecimal=False)) # 可转债权重
 
+class FundOpenInfo(Base):
+    '''基金定开信息'''
+
+    __tablename__ = 'fund_open_info'
+
+    fund_id = Column(CHAR(10), primary_key=True) # 代码
+    desc_name = Column(CHAR(64)) # 基金名称
\ No newline at end of file
