@@ -1,6 +1,6 @@
 from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.dialects.mysql import DOUBLE, DATE, DATETIME
+from sqlalchemy.dialects.mysql import DOUBLE, DATE, DATETIME, SMALLINT
 
 
 class Base():
@@ -209,6 +209,7 @@ class FundIndicatorGroup(Base):
 
     fund_id = Column(CHAR(10), primary_key=True)  # 基金ID
     datetime = Column(DATE, primary_key=True)  # 日期
+    data_cycle = Column(CHAR(3), primary_key=True)  # 使用多长时间的数据来计算
     scale = Column(DOUBLE(asdecimal=False))  # 规模
     beta = Column(DOUBLE(asdecimal=False))
     alpha = Column(DOUBLE(asdecimal=False))
@@ -253,7 +254,7 @@ class FundIndicatorGroup(Base):
     stock_hm_beta_p = Column(DOUBLE(asdecimal=False))  # hm beta p值
 
     __table_args__ = (
-        Index('idx_fund_indicator_group_datetime', 'datetime'),
+        Index('idx_fund_indicator_group_datetime_data_cycle', 'datetime', 'data_cycle'),
     )
 
 
@@ -285,6 +286,7 @@ class FundScoreExtended(Base):
 
     fund_id = Column(CHAR(16), primary_key=True)  # 基金代码
     datetime = Column(DATE, primary_key=True)  # 日期
+    data_cycle = Column(CHAR(3), primary_key=True)  # 使用多长时间的数据来计算
     wind_class_1 = Column(CHAR(16))  # Wind基金一级类型
     ret = Column(DOUBLE(asdecimal=False))  # ret
     vol = Column(DOUBLE(asdecimal=False))  # volatility
@@ -319,7 +321,7 @@ class FundScoreExtended(Base):
     total_rank = Column(DOUBLE(asdecimal=False))  # rank of total
 
     __table_args__ = (
-        Index('idx_fund_score_extended_datetime', 'datetime'),
+        Index('idx_fund_score_extended_datetime_data_cycle', 'datetime', 'data_cycle'),
     )
 
 class FundScoreNew(Base):
@@ -329,6 +331,7 @@ class FundScoreNew(Base):
 
     fund_id = Column(CHAR(16), primary_key=True)  # 基金代码
     datetime = Column(DATE, primary_key=True)  # 日期
+    data_cycle = Column(CHAR(3), primary_key=True)  # 使用多长时间的数据来计算
     wind_class_1 = Column(CHAR(16))  # Wind基金一级类型
     return_score = Column(DOUBLE(asdecimal=False))  # 被动指数型、被动指数型债券(均为二级分类)基金为跟踪标的能力，其他为收益能力
     robust_score = Column(DOUBLE(asdecimal=False))  # 稳定性能力
@@ -339,7 +342,7 @@ class FundScoreNew(Base):
     total_score = Column(DOUBLE(asdecimal=False), nullable=False)  # 总分
 
     __table_args__ = (
-        Index('idx_fund_score_new_datetime', 'datetime'),
+        Index('idx_fund_score_new_data_cycle', 'data_cycle'),
     )
 
 class AssetAllocationInfo(Base):
@@ -492,6 +495,9 @@ class FundManagerScore(Base):
     model_beta = Column(DOUBLE(asdecimal=False))
     score = Column(DOUBLE(asdecimal=False))
 
+    __table_args__ = (
+        Index('idx_fund_manager_score_datetime', 'datetime'),
+    )
 
 class FundManagerInfo(Base):
     '''基金经理信息'''
@@ -541,3 +547,117 @@ class ConvertibleBondFundRank(Base):
     fund_id = Column(CHAR(10), primary_key=True)        # 基金ID
     final_score = Column(DOUBLE(asdecimal=False))       # 最终分数
 
+
+class ThirdPartyPortfolioInfo(Base):
+    '''组合基本信息表'''
+
+    __tablename__ = 'third_party_portfolio_info'
+
+    po_id = Column(CHAR(16), primary_key=True)  # 组合ID
+    po_src = Column(SMALLINT, nullable=False)  # 组合来源 详见constant.SourceType
+    po_name = Column(TEXT, nullable=False)  # 组合名称
+    po_desc = Column(TEXT)  # 组合描述
+    manager_name = Column(TEXT) # 主理人名称
+    rich_desc = Column(TEXT)  # 详细描述
+    benchmarks = Column(TEXT) # 业绩比较基准
+    start_date = Column(DATE, nullable=False)  # 组合开始日期
+    risk_level = Column(CHAR(6))  # 风险级别
+    can_aip = Column(BOOLEAN)  # 是否可定投
+
+
+class ThirdPartyPortfolioTrade(Base):
+    '''组合调仓记录表'''
+
+    __tablename__ = 'third_party_portfolio_trade'
+
+    po_id = Column(CHAR(16), primary_key=True)  # 组合ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    po_src = Column(SMALLINT, nullable=False)  # 组合来源 详见constant.SourceType
+    details = Column(TEXT, nullable=False)  # 调仓详情
+    comment = Column(TEXT)
+
+
+class ThirdPartyPortfolioPositionLatest(Base):
+    '''组合最新持仓表'''
+
+    __tablename__ = 'third_party_portfolio_position_latest'
+
+    po_id = Column(CHAR(16), primary_key=True)  # 组合ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    po_src = Column(SMALLINT, nullable=False)  # 组合来源 详见constant.SourceType
+    position = Column(TEXT, nullable=False)  # 持仓
+
+
+class ThirdPartyPortfolioIndicator(Base):
+    '''组合最新因子表'''
+
+    __tablename__ = 'third_party_portfolio_indicator'
+
+    po_id = Column(CHAR(16), primary_key=True)  # 组合ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    po_src = Column(SMALLINT, nullable=False)  # 组合来源 详见constant.SourceType
+    nav = Column(DOUBLE(asdecimal=False), nullable=False)  # 净值（累计复权净值计算得出）
+    sharpe_ratio = Column(DOUBLE(asdecimal=False))  # 夏普比率
+    mdd = Column(DOUBLE(asdecimal=False), nullable=False)  # 最大回撤
+    annual_compounded_ret = Column(DOUBLE(asdecimal=False), nullable=False)  # 年化复合收益率
+    daily_ret = Column(DOUBLE(asdecimal=False), nullable=False)  # 最近一天收益率
+    weekly_ret = Column(DOUBLE(asdecimal=False))  # 最近一周收益率
+    monthly_ret = Column(DOUBLE(asdecimal=False))  # 最近一月收益率
+    quarterly_ret = Column(DOUBLE(asdecimal=False))  # 最近一季收益率
+    half_yearly_ret = Column(DOUBLE(asdecimal=False))  # 最近半年收益率
+    yearly_ret = Column(DOUBLE(asdecimal=False))  # 最近一年收益率
+    from_setup_ret = Column(DOUBLE(asdecimal=False), nullable=False)  # 成立以来收益率
+    vol_by_day = Column(DOUBLE(asdecimal=False))  # 年化日波动率
+    vol_by_week = Column(DOUBLE(asdecimal=False))  # 年化周波动率
+    vol_by_month = Column(DOUBLE(asdecimal=False))  # 年化月波动率
+    annual_ret = Column(DOUBLE(asdecimal=False), nullable=False)  # 年化收益
+    mdd_d1 = Column(DATE, nullable=False)  # 回撤区间高点日期
+    mdd_d2 = Column(DATE, nullable=False)  # 回撤区间低点日期
+    total_commission = Column(DOUBLE(asdecimal=False), nullable=False)  # 总手续费
+    rebalance_times = Column(DOUBLE(asdecimal=False), nullable=False)  # 调仓次数
+
+class FundIndicatorIPOConv(Base):
+    '''基金评价指标'''
+
+    __tablename__ = 'fund_indicator_ipo_conv'
+    fund_id = Column(CHAR(10), primary_key=True) # 基金ID
+    datetime = Column(DATE, primary_key=True) # 日期
+    beta = Column(DOUBLE(asdecimal=False)) # 风险指数
+    alpha = Column(DOUBLE(asdecimal=False)) # 投资回报
+    track_err = Column(DOUBLE(asdecimal=False)) # 跟踪误差
+    timespan = Column(DOUBLE(asdecimal=False)) # 历史数据跨度(年)
+    fee_rate = Column(DOUBLE(asdecimal=False)) # 费率
+    info_ratio = Column(DOUBLE(asdecimal=False)) # 信息比率
+    treynor = Column(DOUBLE(asdecimal=False)) # 特雷诺比率
+    mdd = Column(DOUBLE(asdecimal=False)) #净值最大回撤
+    down_risk = Column(DOUBLE(asdecimal=False)) #下行风险
+    ret_over_period = Column(DOUBLE(asdecimal=False)) #区间收益率
+    annual_avg_daily_ret = Column(DOUBLE(asdecimal=False)) #年化日均收益
+    annual_vol = Column(DOUBLE(asdecimal=False)) #年化波动率
+    annual_ret = Column(DOUBLE(asdecimal=False)) #年化收益
+    m_square = Column(DOUBLE(asdecimal=False)) #M平方测度 风险调整收益指标
+    time_ret = Column(DOUBLE(asdecimal=False)) #择时收益
+    var = Column(DOUBLE(asdecimal=False)) #资产在险值
+    r_square = Column(DOUBLE(asdecimal=False)) #决定系数R方
+    sharpe = Column(DOUBLE(asdecimal=False)) #夏普率
+    year_length = Column(DOUBLE(asdecimal=False)) #成立年限
+
+    __table_args__ = (
+        Index('idx_fund_indicator_ipo_conv_datetime', 'datetime'),
+    )
+
+class TopManagerFunds(Base):
+    '''基金经理选基'''
+
+    __tablename__ = 'top_manager_funds'
+    datetime = Column(DATE, primary_key=True) # 日期
+    top_1 = Column(CHAR(10))  # 第一名基金
+    top_2 = Column(CHAR(10))  # 第二名基金
+    top_3 = Column(CHAR(10))  # 第三名基金
+    top_4 = Column(CHAR(10))  # 第四名基金
+    top_5 = Column(CHAR(10))  # 第五名基金
+    top_6 = Column(CHAR(10))  # 第六名基金
+    top_7 = Column(CHAR(10))  # 第七名基金
+    top_8 = Column(CHAR(10))  # 第八名基金
+    top_9 = Column(CHAR(10))  # 第九名基金
+    top_10 = Column(CHAR(10)) # 第十名基金
\ No newline at end of file
