@@ -1,7 +1,7 @@
 
 from sqlalchemy import CHAR, Column, Integer, TEXT, BOOLEAN, text, Index, Enum
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.dialects.mysql import DOUBLE, DATE, TINYINT, DATETIME, MEDIUMTEXT, YEAR
+from sqlalchemy.dialects.mysql import DOUBLE, DATE, TINYINT, DATETIME, MEDIUMTEXT, YEAR, SMALLINT
 
 from ...constant import SectorType, IndexPriceSource, CodeFeeMode
 
@@ -1308,7 +1308,11 @@ class EmMacroEconomicDaily(Base):
     __tablename__ = 'em_macro_economic_daily'
 
     # TB_1Y: 中债国债到期收益率：1年
+    # TB_3Y: 中债国债到期收益率：3年
+    # TB_5Y: 中债国债到期收益率：5年
     # TB_10Y: 中债国债到期收益率：10年
+    # SHIBOR_1M: 1个月SHIBOR
+    # SHIBOR_3M: 3个月SHIBOR
     # CB_AAA_1Y: 交易所公司债到期收益率(AAA):1年
     codes = Column(CHAR(12), primary_key=True)
     datetime = Column(DATE, primary_key=True) # 日期
@@ -1369,7 +1373,7 @@ class EmFundConvInfo(Base):
     em_industry = Column(CHAR(20)) # 东财行业
 
 class EmFundIPODetail(Base):
-    '''打新明细''' 
+    '''打新明细'''
     #TODO 东财这部分下数据接口在11月上限，当前没有直接使用，通过客户端接口下载csv数据倒入数据库，只有一个基金明细
 
     __tablename__ = 'em_fund_ipo_detail'
@@ -1389,3 +1393,87 @@ class EmFundIPODetail(Base):
     annual_allocation_ret = Column(DOUBLE(asdecimal=False)) # 年化打新收益率(%)
     industry = Column(CHAR(40)) # 证监会行业(2012)
     em_industry = Column(CHAR(20)) # 东财行业
+
+
+class EmFundOpen(Base):
+    '''东财定期开放基金'''
+
+    __tablename__ = 'em_fund_open'
+    em_id = Column(CHAR(10), primary_key=True) # 基金代码
+    desc_name = Column(CHAR(20)) # 名称
+
+
+class EmStockIndustrialCapital(Base):
+    '''Choice产业资本流动数据'''
+
+    __tablename__ = 'em_stock_industrial_capital'
+
+    datetime = Column(DATE, primary_key=True)  # 日期
+    period = Column(CHAR(1), primary_key=True)  # 时间周期(D/W/M/Y)
+    inc_amt_all = Column(DOUBLE(asdecimal=False))  # 全市场增持金额
+    inc_amt_gem = Column(DOUBLE(asdecimal=False))  # 创业板增持金额
+    dec_amt_all = Column(DOUBLE(asdecimal=False))  # 全市场减持金额
+    dec_amt_gem = Column(DOUBLE(asdecimal=False))  # 创业板减持金额
+
+class EmStockIndustrialCapitalTradeDetail(Base):
+    '''Choice产业资本二级市场交易明细'''
+
+    __tablename__ = 'em_stock_industrial_capital_trade_detail'
+
+    sec_code = Column(CHAR(10), primary_key=True)  # EM股票ID
+    notice_date = Column(DATE, primary_key=True)  # 公告日期
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    share_hd_type = Column(CHAR(2), nullable=False)  # 股东类型
+    share_hd_name = Column(TEXT, nullable=False)  # 股东名称
+    is_ctrl = Column(CHAR(1), nullable=False)  # 是否实际控制人
+    position1 = Column(TEXT)  # 高管职务
+    fx = Column(CHAR(2), nullable=False)  # 方向
+    change_num = Column(DOUBLE(asdecimal=False), nullable=False)  # 变动_流通股数量(万股)
+    bdsl_zltb = Column(DOUBLE(asdecimal=False))  # 变动_占流通股比例(%)
+    tg_dzjy_ptzr = Column(DOUBLE(asdecimal=False))  # 变动_大宗交易转让(万股)
+    bdh_cyltgsl = Column(DOUBLE(asdecimal=False))  # 变动后_持流通股数量(万股)
+    bdh_cyltslzltgb = Column(DOUBLE(asdecimal=False))  # 变动后_占流通股比例(%)
+    bdh_cgzs = Column(DOUBLE(asdecimal=False))  # 变动后_持股总数
+    bdh_cgbl = Column(DOUBLE(asdecimal=False))  # 变动后_占总股本比例(%)
+    jyp_jj = Column(DOUBLE(asdecimal=False))  # 成交均价(元)
+    latest_price = Column(DOUBLE(asdecimal=False))  # 最新收盘价(元)
+    dec_jypjj_rate = Column(DOUBLE(asdecimal=False))  # 最新价格交成交均价涨跌幅(%)
+    bdqj_gpjj = Column(DOUBLE(asdecimal=False))  # 变动期间股票均价(元)
+    bdbf_cksz = Column(DOUBLE(asdecimal=False))  # 变动部分参考市值(元)
+    bd_qsrq = Column(DATE, nullable=False)  # 变动起始日期
+    bd_jzrq = Column(DATE, nullable=False)  # 变动截止日期
+    clb_remark = Column(TEXT)  # 说明
+    publish_name_dc3 = Column(TEXT, nullable=False)  # 东财三级行业
+    trade_type = Column(TEXT, nullable=False)  # 变动类型
+
+class EmSHSZToHKStockConnect(Base):
+    '''Choice沪深股通(即北向)活跃成交股'''
+
+    __tablename__ = 'em_stock_to_hk_connect'
+
+    datetime = Column(DATE, primary_key=True)  # 日期
+    market = Column(CHAR(2), primary_key=True)  # 市场(SH/SZ)
+    period = Column(CHAR(1), primary_key=True)  # 时间周期(D/W/M/Y)
+    dec_rank = Column(SMALLINT, primary_key=True)  # 排名
+    msecu_code = Column(CHAR(10), nullable=False)  # EM股票ID
+    bmoney = Column(DOUBLE(asdecimal=False), nullable=False)  # 买入金额(万元)
+    smoney = Column(DOUBLE(asdecimal=False), nullable=False)  # 卖出金额(万元)
+    tval = Column(DOUBLE(asdecimal=False), nullable=False)  # 沪/深股通成交金额(万元)
+    ztval = Column(DOUBLE(asdecimal=False), nullable=False)  # 总成交金额(万元)
+    zsz = Column(DOUBLE(asdecimal=False), nullable=False)  # 总市值(亿元)
+    cnt = Column(Integer, nullable=False)  # 累计上榜次数
+    publish_name_dc3 = Column(TEXT, nullable=False)  # 东财行业
+
+class EmStockResearchInfo(Base):
+    '''Choice机构调研上市公司信息'''
+
+    __tablename__ = 'em_stock_research_info'
+
+    CODES = Column('em_id', CHAR(10), primary_key=True) # EM股票ID
+    DATES = Column('datetime', DATE, primary_key=True)  # 日期
+    RESERCHNUM = Column('research_num', DOUBLE(asdecimal=False), nullable=False)  # 接待量
+    RESERCHINSTITUTENUM = Column('research_institute_num', DOUBLE(asdecimal=False))  # 机构来访接待量
+    RESERCHOTHERNUM = Column('research_other_num', DOUBLE(asdecimal=False))  # 其他来访接待量
+    RESERCHSECUNUM = Column('research_secu_num', DOUBLE(asdecimal=False))  # 证券公司调研家数
+    RESERCHSECUNAME = Column('research_ecu_name', TEXT)  # 调研的证券公司
+    RESERCHSECUFREQUENCY1 = Column('research_secu_freq1', DOUBLE(asdecimal=False))  # 证券公司调研频次
