@@ -41,6 +41,7 @@ class FundDailyCollection(Base):
     adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
     change_rate = Column(DOUBLE(asdecimal=False))  # 日收益率
     found_date = Column(CHAR(20))  # 成立日期
+    end_date = Column(CHAR(20))  # 关闭日期
     annualized_returns = Column(DOUBLE(asdecimal=False))  # 成立以来年化收益率
     annualized_risk = Column(DOUBLE(asdecimal=False))  # 成立以来年化风险
     information_ratio = Column(DOUBLE(asdecimal=False))  # 成立以来信息比率
@@ -152,6 +153,7 @@ class FundDailyCollection(Base):
             'acc_net_value': '累计净值',
             'change_rate': '日收益率',
             'found_date': '成立日期',
+            'end_date': '关闭日期',
             'annualized_returns': '年化收益',
             'annualized_risk': '成立以来年化风险',
             'information_ratio': '成立以来信息比率',
