@@ -163,7 +163,7 @@ class FAHelper(Helper):
         
         # if no fund in index_id, rebalance again
         for index_id, w in cur_asset_allocation.__dict__.items():
-            if w == 0:
+            if w == 0 or index_id == 'cash':
                 continue
             _score_dic = cur_fund_score[index_id][score_select_dict[index_id]]
             if not _score_dic:
