@@ -11,7 +11,7 @@ import datetime
 
 class AssetTrader(Helper):
 
-    TRADE_DAY_INTERVAL = 10
+    TRADE_DAY_INTERVAL = 20
     DEFAULT_CASH_VALUE = _DEFAULT_CASH_VALUE
 
     def __init__(self, asset_param: AssetTradeParam=None):
@@ -136,6 +136,7 @@ class FundTrader(AssetTrader):
     def __init__(self, asset_param: AssetTradeParam=None, fund_param: FundTradeParam=None):
         AssetTrader.__init__(self, asset_param=asset_param)
         self.fund_param = fund_param or FundTradeParam()
+        self.pos_manager_list = []
 
     def set_helper(self, fa_helper: FAHelper):
         self.fa_helper = fa_helper
@@ -208,11 +209,12 @@ class FundTrader(AssetTrader):
                             cur_fund_unit_nav: dict,
                             fund_purchase_fees: dict,
                             fund_redeem_fees: dict,
-                            disproved_set: set):
+                            disproved_set: set,
+                            tar_fund_weight: FundWeight):
 
         if trades is None or len(trades) == 0:
             return [], []
-
+        self.pos_manager_list = tar_fund_weight.get_funds('active')
         pendings = []
         traded_list = []
         # TODO: if some trades needs more time
@@ -273,6 +275,8 @@ class FundTrader(AssetTrader):
             trade_status = cur_fund_position.update(trd)
             if trade_status:
                 traded_list.append(trd)
+                if trd.fund_id in disproved_set:
+                    print(f' trade bannded fund dt {dt} fund_id {trd.fund_id} index_id {trd,index_id}')
             else:
                 pass
                 #print(f'trade failed alert : {trd}')
@@ -310,7 +314,8 @@ class FundTrader(AssetTrader):
             cur_asset_position: AssetPosition,
             cur_fund_nav: dict,
             cur_fund_score: dict,
-            cur_asset_price: AssetPrice) -> bool:
+            cur_asset_price: AssetPrice,
+            score_select: dict) -> bool:
 
         index_rebalance_max_diff = 0
         fund_selection_min_score = 1
@@ -335,14 +340,18 @@ class FundTrader(AssetTrader):
 
             c.fund_cur_wgts = cur_fund_position.calc_mv_n_w(cur_fund_nav, index_id)[1]
             c.cur_fund_ids = set(c.fund_cur_wgts.keys())
-            c.fund_scores = sorted(cur_fund_score.get(index_id, {}).items(), key=lambda item: item[1], reverse=True)
+            type_i = score_select[index_id]
+            
+            c.fund_scores = sorted(cur_fund_score.get(index_id, {}).get(type_i, {}).items(), key=lambda item: item[1], reverse=True)
+            
             c.fund_ranks = {info[0]: rank + 1 for rank, info in enumerate(c.fund_scores)}
             c.proper_fund_num = min(self.fa_helper.get_max_fund_num(index_id), len(c.fund_scores)) if index_tar_wgt > self.SMALL_POS_FLOAT else 0
             # 维度1：现有基金的选取优化情况：（评估整体现有基金池的好坏）
             c.fund_judge_ranking_score = 0
             wgt_func = lambda _rank: 1.0 / math.pow(_rank, 1/3)
             _rank_list = []
-            for f in c.cur_fund_ids:
+            _fund_list = self.pos_manager_list if index_id == 'active' else c.cur_fund_ids     
+            for f in _fund_list:
                 rank_i = c.fund_ranks.get(f, self.BIG_INT)
                 if rank_i == self.BIG_INT:
                     fund_end = 1
@@ -373,10 +382,11 @@ class FundTrader(AssetTrader):
             assert len(c.cur_fund_ids) >= c.proper_fund_num, 'cur fund id candidate should be no less than proper_fund_num'
             
             if index_tar_wgt > self.fund_param.DiffJudgeAssetWgtRequirement:
-                if fund_selection_min_score > c.fund_judge_ranking:
-                    fund_selection_min_score = c.fund_judge_ranking
-                    _fund_selection_min_name = index_id
-                    fund_rank_list = _rank_list
+                if index_id != 'mmf':
+                    if fund_selection_min_score > c.fund_judge_ranking:
+                        fund_selection_min_score = c.fund_judge_ranking
+                        _fund_selection_min_name = index_id
+                        fund_rank_list = _rank_list
 
                 if fund_rebalance_min_score > c.fund_judge_diverse:
                     fund_rebalance_min_score = c.fund_judge_diverse
@@ -407,6 +417,9 @@ class FundTrader(AssetTrader):
             if self.trade_interval_allow(dt):
                 #print(f'judge allow {dt} (trigger){TradeTrigger.parse(trigger)} (Fs){fund_selection_min_score}[{_fund_selection_min_name}]#{self.fund_param.JudgeFundSelection} (Fr){fund_rebalance_min_score}/[{_fund_rebalance_min_name}]#{self.fund_param.JudgeFundRebalance} (Ir){index_rebalance_max_diff}/[{_index_rebalance_max_diff_name}]#{self.fund_param.JudgeIndexDiff}')
                 pass
+            elif (not self.trade_interval_allow(dt)) and TradeTrigger.is_end(trigger):
+                #print(f'{dt}  fund end trigger rebalance when not allow trigger {trigger} trigger_reason {trigger_reason}')
+                pass
             else:
                 trigger = 0
                 #print(f'judge dismiss {dt} (trigger){TradeTrigger.parse(trigger)} (Fs){fund_selection_min_score}[{_fund_selection_min_name}]#{self.fund_param.JudgeFundSelection} (Fr){fund_rebalance_min_score}/[{_fund_rebalance_min_name}]#{self.fund_param.JudgeFundRebalance} (Ir){index_rebalance_max_diff}/[{_index_rebalance_max_diff_name}]#{self.fund_param.JudgeIndexDiff}')
@@ -421,7 +434,9 @@ class FundTrader(AssetTrader):
             cur_fund_score: dict,
             cur_asset_price: AssetPrice,
             cur_fund_unit_nav: dict,
-            is_real_trade: bool) -> list:
+            is_real_trade: bool,
+            cur_manager_funds: dict,
+            score_select: dict) -> list:
         '''
         v_asset_position, asset_trade_list = self.calc_asset_trade(dt, cur_asset_position, cur_asset_price, tar_asset_weight)
         if not asset_trade_list:
@@ -437,12 +452,12 @@ class FundTrader(AssetTrader):
             trigger, trigger_reason = self.judge_trade(dt, index_fund_cache, 
                                         tar_fund_weight, tar_asset_weight,
                                         cur_fund_position, cur_asset_position, cur_fund_unit_nav, 
-                                        cur_fund_score, cur_asset_price)
+                                        cur_fund_score, cur_asset_price, score_select)
         else:
             trigger, trigger_reason = self.judge_trade(dt, index_fund_cache, 
                                         tar_fund_weight, tar_asset_weight,
                                         cur_fund_position, cur_asset_position, cur_fund_nav, 
-                                        cur_fund_score, cur_asset_price)
+                                        cur_fund_score, cur_asset_price, score_select)
         
         # 如果是真实交易 且cash 不为零，按照当日cash，返回买单
         if (is_real_trade is False and trigger == 0) or (is_real_trade is True and cur_fund_position.cash == 0 and trigger == 0):
@@ -451,7 +466,7 @@ class FundTrader(AssetTrader):
         fund_trades = self.get_trades(dt, index_fund_cache, 
                                     tar_fund_weight, tar_asset_weight,
                                     cur_fund_position, cur_asset_position, cur_fund_nav, 
-                                    cur_fund_score, cur_asset_price, cur_fund_unit_nav, is_real_trade)
+                                    cur_fund_score, cur_asset_price, cur_fund_unit_nav, is_real_trade, cur_manager_funds)
         fund_trades.sort(key=lambda x: x.is_buy)
         new_fund_position = cur_fund_position.copy()
 
@@ -470,7 +485,12 @@ class FundTrader(AssetTrader):
             cur_fund_score: dict,
             cur_asset_price: AssetPrice,
             cur_fund_unit_nav: dict,
-            is_real_trade: bool):
+            is_real_trade: bool,
+            cur_manager_funds: dict):
+
+        # 只对不含重复头名基金的基金经理做映射
+        _tar_mng_list = tar_fund_weight.get_funds('active')
+        cur_funds_manager = {f:m for m,f in cur_manager_funds.items() if m in _tar_mng_list}
         # 如果是真实交易， 把单位份额赋值给复权份额， 价格不用后复权，用真实单位净值
         if is_real_trade:
             fund_tot_mv, cur_fund_wgts = cur_fund_position.calc_mv_n_w(fund_navs=cur_fund_unit_nav)
@@ -479,14 +499,18 @@ class FundTrader(AssetTrader):
         fund_trades = []
         for c in index_fund_cache:
             index_id = c.index_id
+            # 主动型基金， tar_fund_list 实际是基金经理 列表 需要转换为基金序列
             tar_fund_list = tar_fund_weight.get_funds(index_id)
+            if index_id == 'active':
+                tar_fund_list = [cur_manager_funds[i] for i in tar_fund_list]
             cur_fund_list = cur_fund_position.get_funds(index_id)
             for fund_id in set(tar_fund_list).union(cur_fund_list):
-                target_fund_amt = tar_fund_weight.get_wgt(fund_id) * fund_tot_mv
+                _id = cur_funds_manager[fund_id] if (index_id == 'active') and (fund_id in cur_funds_manager) else fund_id
+                
+                target_fund_amt = tar_fund_weight.get_wgt(_id) * fund_tot_mv
                 cur_fund_volume = cur_fund_position.get_volume(fund_id) or 0
                 p = cur_fund_unit_nav[fund_id] if is_real_trade else cur_fund_nav[fund_id]
                 cur_fund_amt = cur_fund_volume * p
-
                 if abs(target_fund_amt - cur_fund_amt) > fund_tot_mv * self.fund_param.MinCountAmtDiff \
                     or (target_fund_amt == 0 and cur_fund_amt > 0):
                     # 如果是清某一只基金的逻辑，清空可以执行
