@@ -32,11 +32,11 @@ class DataStore:
         return data
 
     @staticmethod
-    def refresh_dm(score_pre_calc=True,start_time='20050101',print_time=False,use_weekly_monthly_indicators=False,is_normal_type=False,is_mix_type=False):
+    def refresh_dm(score_pre_calc=True,start_time='20050101',print_time=False,use_weekly_monthly_indicators=False,s3_retriever_activation=False):
         print(f'start load at {datetime.datetime.now()}')
         t1 = time.time()
-        dm = FundDataManager(start_time=start_time, end_time=datetime.datetime.now().strftime('%Y%m%d'))
-        dm.init(score_pre_calc=score_pre_calc, print_time=print_time, use_weekly_monthly_indicators=use_weekly_monthly_indicators,is_normal_type=is_normal_type,is_mix_type=is_mix_type)
+        dm = FundDataManager(start_time=start_time, end_time=datetime.datetime.now().strftime('%Y%m%d'), s3_retriever_activation=s3_retriever_activation)
+        dm.init(score_pre_calc=score_pre_calc, print_time=print_time, use_weekly_monthly_indicators=use_weekly_monthly_indicators)
         DataStore.store(dm, DataStore.DATA_MANAGER_PATH)
         t2 = time.time()
         print(f'refresh dm cost time {t2 - t1}s')
