@@ -25,6 +25,7 @@ class SeriesStatUnit:
     annualized_ret: float       # 年化收益
     annualized_vol: float       # 年化波动率
     sharpe: float               # 夏普率
+    recent_y1_ret: float        # 近一年收益
     recent_y5_ret: float        # 近五年收益 
     mdd: float                  # 最大回撤
     mdd_date1: datetime.date    # 最大回撤开始时间
@@ -32,6 +33,9 @@ class SeriesStatUnit:
     ret_over_mdd: float         # Calmar 年化收益除以最大回撤
     last_mv_diff: float         # 末期市值增量              
     last_increase_rate: float   # 末期涨幅
+    worst_3m_ret: float         # 最差三月收益
+    worst_6m_ret: float         # 最差六月收益
+    recent_drawdown: float      # 最近回撤
 
 @dataclasses.dataclass
 class BenchmarkSeiesStatUnit(SeriesStatUnit):
@@ -80,10 +84,18 @@ class Calculator:
             annualized_ret = np.exp(np.log(last_unit_nav) / trade_year) - 1
             annualized_vol = (sr / sr.shift(1)).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier)
             sharpe = (annualized_ret - risk_fee_rate) / annualized_vol
+            recent_drawdown = 1 - (sr[-1] / sr.max())
             if sr.shape[0] * yearly_multiplier > Calculator.TRADING_DAYS_PER_YEAR * 5:
                 recent_y5_ret  = sr[-1] / sr[- int(Calculator.TRADING_DAYS_PER_YEAR * 5 / yearly_multiplier)] - 1
             else:
                 recent_y5_ret = sr[-1] / sr[0] - 1
+
+            if sr.shape[0] * yearly_multiplier > Calculator.TRADING_DAYS_PER_YEAR:
+                recent_y1_ret  = sr[-1] / sr[- int(Calculator.TRADING_DAYS_PER_YEAR * 1 / yearly_multiplier)] - 1
+            else:
+                recent_y1_ret = sr[-1] / sr[0] - 1
+            worst_3m_ret = sr.pct_change(60).min()
+            worst_6m_ret = sr.pct_change(120).min()
             mdd_part =  sr[:] / sr[:].rolling(window=sr.shape[0], min_periods=1).max()
             mdd = 1 - mdd_part.min()
             if np.isnan(mdd):
@@ -99,6 +111,7 @@ class Calculator:
         else:
             start_date = dates[0] if len(dates) > 0 else None
             end_date = dates[0] if len(dates) > 0 else None
+            recent_y1_ret = 0
             trade_year = 0
             last_unit_nav = 1
             annualized_ret = 0
@@ -111,6 +124,9 @@ class Calculator:
             ret_over_mdd = 0
             last_mv_diff = 0
             last_increase_rate = 0
+            recent_drawdown = 0
+            worst_3m_ret = 0
+            worst_6m_ret = 0
 
         return SeriesStatUnit(
             start_date=start_date,
@@ -120,13 +136,17 @@ class Calculator:
             annualized_ret=annualized_ret,
             annualized_vol=annualized_vol,
             sharpe=sharpe,
+            recent_y1_ret=recent_y1_ret,
             recent_y5_ret=recent_y5_ret,
+            worst_3m_ret=worst_3m_ret,
+            worst_6m_ret=worst_6m_ret,     
             mdd=mdd,
             mdd_date1=mdd_date1,
             mdd_date2=mdd_date2,
             ret_over_mdd=ret_over_mdd,
             last_mv_diff=last_mv_diff,
             last_increase_rate=last_increase_rate,
+            recent_drawdown=recent_drawdown,
         )
 
     @staticmethod
@@ -253,6 +273,10 @@ class Calculator:
             ir=ir,
             last_mv_diff=res.last_mv_diff,
             last_increase_rate=res.last_increase_rate,
+            recent_y1_ret=res.recent_y1_ret,
+            worst_3m_ret=res.worst_3m_ret,
+            worst_6m_ret=res.worst_6m_ret,
+            recent_drawdown=res.recent_drawdown,
         )
 
     @staticmethod
